@@ -712,8 +712,8 @@ int cylinderuse_from_text(const char *text);
 
 
 struct user_info {
-	const char *name;
-	const char *email;
+	char *name;
+	char *email;
 };
 
 extern void subsurface_user_info(struct user_info *);
@@ -761,6 +761,7 @@ extern int dive_getUniqID(struct dive *d);
 extern unsigned int dc_airtemp(struct divecomputer *dc);
 extern unsigned int dc_watertemp(struct divecomputer *dc);
 extern int split_dive(struct dive *);
+extern void split_dive_at_time(struct dive *dive, duration_t time);
 extern struct dive *merge_dives(struct dive *a, struct dive *b, int offset, bool prefer_downloaded);
 extern struct dive *try_to_merge(struct dive *a, struct dive *b, bool prefer_downloaded);
 extern struct event *clone_event(const struct event *src_ev);
