@@ -41,6 +41,7 @@
 #include <libxslt/transform.h>
 
 #include "dive.h"
+#include "subsurface-string.h"
 #include "divelist.h"
 #include "display.h"
 #include "planner.h"
@@ -202,7 +203,7 @@ double calculate_cns_dive(struct dive *dive)
 	size_t j;
 	struct divecomputer *dc = &dive->dc;
 	double cns = 0.0;
-	
+
 	/* Caclulate the CNS for each sample in this dive and sum them */
 	for (n = 1; n < dc->samples; n++) {
 		int t;
@@ -226,7 +227,7 @@ double calculate_cns_dive(struct dive *dive)
 		j--;
 		cns += ((double)t) / ((double)cns_table[j][1]) * 100;
 	}
-	
+
 	return cns;
 }
 
@@ -246,9 +247,9 @@ static int calculate_cns(struct dive *dive)
 	divenr = get_divenr(dive);
 	i = divenr >= 0 ? divenr : dive_table.nr;
 #if DECO_CALC_DEBUG & 2
-	if (i >= 0 && i < dive_table.nr) 
+	if (i >= 0 && i < dive_table.nr)
 		printf("\n\n*** CNS for dive #%d %d\n", i, get_dive(i)->number);
-	else 
+	else
 		printf("\n\n*** CNS for dive #%d\n", i);
 #endif
 	/* Look at next dive in dive list table and correct i when needed */
@@ -281,7 +282,7 @@ static int calculate_cns(struct dive *dive)
 		 * for how far back we need to go */
 		if (dive->divetrip && pdive->divetrip != dive->divetrip) {
 #if DECO_CALC_DEBUG & 2
-			printf("No - other dive trip\n"); 
+			printf("No - other dive trip\n");
 #endif
 			continue;
 		}
@@ -305,7 +306,7 @@ static int calculate_cns(struct dive *dive)
 		/* again skip dives from different trips */
 		if (dive->divetrip && dive->divetrip != pdive->divetrip) {
 #if DECO_CALC_DEBUG & 2
-			printf("No - other dive trip\n"); 
+			printf("No - other dive trip\n");
 #endif
 			continue;
 		}
@@ -328,7 +329,7 @@ static int calculate_cns(struct dive *dive)
 #endif
 
 		/* CNS reduced with 90min halftime during surface interval */
-		if (last_endtime) 
+		if (last_endtime)
 			cns /= pow(2, (pdive->when - last_endtime) / (90.0 * 60.0));
 #if DECO_CALC_DEBUG & 2
 		printf("CNS after surface interval: %f\n", cns);
@@ -342,7 +343,7 @@ static int calculate_cns(struct dive *dive)
 		last_starttime = pdive->when;
 		last_endtime = dive_endtime(pdive);
 	}
-	
+
 	/* CNS reduced with 90min halftime during surface interval */
 	if (last_endtime)
 		cns /= pow(2, (dive->when - last_endtime) / (90.0 * 60.0));
@@ -373,8 +374,16 @@ static double calculate_airuse(struct dive *dive)
 
 		start = cyl->start.mbar ? cyl->start : cyl->sample_start;
 		end = cyl->end.mbar ? cyl->end : cyl->sample_end;
-		if (!end.mbar || start.mbar <= end.mbar)
-			continue;
+		if (!end.mbar || start.mbar <= end.mbar) {
+			// If a cylinder is used but we do not have info on amout of gas used
+			// better not pretend we know the total gas use.
+			// Eventually, logic should be fixed to compute average depth and total time
+			// for those segments where cylinders with known pressure drop are breathed from.
+			if (is_cylinder_used(dive, i))
+				return 0.0;
+			else
+				continue;
+		}
 
 		airuse += gas_volume(cyl, start) - gas_volume(cyl, end);
 	}
@@ -413,8 +422,9 @@ static void add_dive_to_deco(struct deco_state *ds, struct dive *dive)
 {
 	struct divecomputer *dc = &dive->dc;
 	struct gasmix *gasmix = NULL;
-	struct event *ev = NULL;
 	int i;
+	struct event *ev = NULL, *evd = NULL;
+	enum divemode_t current_divemode = UNDEF_COMP_TYPE;
 
 	if (!dc)
 		return;
@@ -429,7 +439,8 @@ static void add_dive_to_deco(struct deco_state *ds, struct dive *dive)
 		for (j = t0; j < t1; j++) {
 			int depth = interpolate(psample->depth.mm, sample->depth.mm, j - t0, t1 - t0);
 			gasmix = get_gasmix(dive, dc, j, &ev, gasmix);
-			add_segment(ds, depth_to_bar(depth, dive), gasmix, 1, sample->setpoint.mbar, dive, dive->sac);
+			add_segment(ds, depth_to_bar(depth, dive), gasmix, 1, sample->setpoint.mbar,
+				get_current_divemode(&dive->dc, j, &evd, &current_divemode), dive->sac);
 		}
 	}
 }
@@ -516,7 +527,7 @@ int init_decompression(struct deco_state *ds, struct dive *dive)
 		 * for how far back we need to go */
 		if (dive->divetrip && pdive->divetrip != dive->divetrip) {
 #if DECO_CALC_DEBUG & 2
-			printf("No - other dive trip\n"); 
+			printf("No - other dive trip\n");
 #endif
 			continue;
 		}
@@ -540,7 +551,7 @@ int init_decompression(struct deco_state *ds, struct dive *dive)
 		/* again skip dives from different trips */
 		if (dive->divetrip && dive->divetrip != pdive->divetrip) {
 #if DECO_CALC_DEBUG & 2
-			printf("No - other dive trip\n"); 
+			printf("No - other dive trip\n");
 #endif
 			continue;
 		}
@@ -583,7 +594,7 @@ int init_decompression(struct deco_state *ds, struct dive *dive)
 #endif
 				return surface_time;
 			}
-			add_segment(ds, surface_pressure, &air, surface_time, 0, dive, prefs.decosac);
+			add_segment(ds, surface_pressure, &air, surface_time, 0, dive->dc.divemode, prefs.decosac);
 #if DECO_CALC_DEBUG & 2
 			printf("Tissues after surface intervall of %d:%02u:\n", FRACTION(surface_time, 60));
 			dump_tissues(ds);
@@ -605,7 +616,7 @@ int init_decompression(struct deco_state *ds, struct dive *dive)
 	/* We don't have had a previous dive at all? */
 	if (!deco_init) {
 #if DECO_CALC_DEBUG & 2
-		printf("Init deco\n");		
+		printf("Init deco\n");
 #endif
 		clear_deco(ds, surface_pressure);
 #if DECO_CALC_DEBUG & 2
@@ -621,7 +632,7 @@ int init_decompression(struct deco_state *ds, struct dive *dive)
 #endif
 			return surface_time;
 		}
-		add_segment(ds, surface_pressure, &air, surface_time, 0, dive, prefs.decosac);
+		add_segment(ds, surface_pressure, &air, surface_time, 0, dive->dc.divemode, prefs.decosac);
 #if DECO_CALC_DEBUG & 2
 		printf("Tissues after surface intervall of %d:%02u:\n", FRACTION(surface_time, 60));
 		dump_tissues(ds);
