@@ -44,52 +44,80 @@ void ImageDownloader::saveImage(QNetworkReply *reply)
 		emit failed(filename);
 	} else {
 		QByteArray imageData = reply->readAll();
-		QCryptographicHash hash(QCryptographicHash::Sha1);
-		hash.addData(imageData);
-		QString path = QStandardPaths::standardLocations(QStandardPaths::CacheLocation).first();
-		QDir dir(path);
-		if (!dir.exists())
-			dir.mkpath(path);
-		QFile imageFile(path.append("/").append(hash.result().toHex()));
-		if (imageFile.open(QIODevice::WriteOnly)) {
-			qDebug() << "Write image to" << imageFile.fileName();
-			QDataStream stream(&imageFile);
-			stream.writeRawData(imageData.data(), imageData.length());
-			imageFile.waitForBytesWritten(-1);
-			imageFile.close();
-			learnHash(filename, imageFile.fileName(), hash.result());
+		if (imageData.isEmpty()) {
+			emit failed(filename);
+		} else {
+			QString path = QStandardPaths::standardLocations(QStandardPaths::CacheLocation).first();
+			QDir dir(path);
+			if (!dir.exists())
+				dir.mkpath(path);
+			QCryptographicHash hash(QCryptographicHash::Sha1);
+			hash.addData(filename.toUtf8());
+			QFile imageFile(path.append("/").append(hash.result().toHex()));
+			if (imageFile.open(QIODevice::WriteOnly)) {
+				qDebug() << "Write image to" << imageFile.fileName();
+				QDataStream stream(&imageFile);
+				stream.writeRawData(imageData.data(), imageData.length());
+				imageFile.waitForBytesWritten(-1);
+				imageFile.close();
+				learnPictureFilename(filename, imageFile.fileName());
+			}
+			emit loaded(filename);
 		}
-		emit loaded(filename);
 	}
 
 	reply->deleteLater();
 }
 
-// Fetch a picture from the given filename. If this is a non-remote filename, fetch it from disk.
-// Remote files are fetched from the net in a background thread. In such a case, the output-flag
-// "stillLoading" is set to true.
+static bool hasVideoFileExtension(const QString &filename)
+{
+	for (const QString &ext: videoExtensionsList)
+		if (filename.endsWith(ext, Qt::CaseInsensitive))
+			return true;
+	return false;
+}
+
+// Fetch a picture from the given filename and determine its type (picture of video).
+// If this is a non-remote file, fetch it from disk. Remote files are fetched from the
+// net in a background thread. In such a case, the output-type is set to MEDIATYPE_STILL_LOADING.
 // If the input-flag "tryDownload" is set to false, no download attempt is made. This is to
 // prevent infinite loops, where failed image downloads would be repeated ad infinitum.
-// Returns: fetched image, stillLoading flag
-static std::pair<QImage, bool> fetchImage(const QString &filename, const QString &originalFilename, bool tryDownload)
+// Returns: fetched image, type
+Thumbnailer::Thumbnail Thumbnailer::fetchImage(const QString &filename, const QString &originalFilename, bool tryDownload)
 {
-	QImage thumb;
-	bool stillLoading = false;
 	QUrl url = QUrl::fromUserInput(filename);
 	if (url.isLocalFile()) {
-		thumb.load(url.toLocalFile());
-		// If we loaded successfully, make sure the hash is up to date.
-		// Note that hashPicture() takes the *original* filename.
+		// We try to determine the type first by peeking into the file.
+		QString filename = url.toLocalFile();
+		metadata md;
+		mediatype_t type = get_metadata(qPrintable(filename), &md);
+
+		// For io error or video, return early with the appropriate dummy-icon.
+		if (type == MEDIATYPE_IO_ERROR)
+			return { failImage, MEDIATYPE_IO_ERROR };
+		else if (type == MEDIATYPE_VIDEO)
+			return { videoImage, MEDIATYPE_VIDEO };
+
+		// Try if Qt can parse this image. If it does, use this as a thumbnail.
+		QImage thumb(filename);
 		if (!thumb.isNull())
-			hashPicture(originalFilename);
+			return { thumb, MEDIATYPE_PICTURE };
+
+		// Neither our code, nor Qt could determine the type of this object from looking at the data.
+		// Try to check for a video-file extension.
+		if (hasVideoFileExtension(filename))
+			return { videoImage, MEDIATYPE_VIDEO };
+
+		// Give up: we simply couldn't determine what this thing is.
+		return { unknownImage, MEDIATYPE_UNKNOWN };
 	} else if (tryDownload) {
 		// This has to be done in UI main thread, because QNetworkManager refuses
 		// to treat requests from other threads. invokeMethod() is Qt's way of calling a
 		// function in a different thread, namely the thread the called object is associated to.
 		QMetaObject::invokeMethod(ImageDownloader::instance(), "load", Qt::AutoConnection, Q_ARG(QUrl, url), Q_ARG(QString, originalFilename));
-		stillLoading = true;
+		return { QImage(), MEDIATYPE_STILL_LOADING };
 	}
-	return { thumb, stillLoading };
+	return { QImage(), MEDIATYPE_IO_ERROR };
 }
 
 // Fetch a picture based on its original filename. If there is a translated filename (obtained either
@@ -98,25 +126,26 @@ static std::pair<QImage, bool> fetchImage(const QString &filename, const QString
 // was downloaded previously, but for some reason the cached picture was lost. Therefore, in such a
 // case, try the canonical filename. If that likewise fails, give up. For input and output parameters
 // see fetchImage() above.
-static std::pair<QImage, bool> getHashedImage(const QString &filename, bool tryDownload)
+Thumbnailer::Thumbnail Thumbnailer::getHashedImage(const QString &filename, bool tryDownload)
 {
-	QImage thumb;
-	bool stillLoading = false;
 	QString localFilename = localFilePath(filename);
 
-	// If there is a translated filename, try that first
+	// If there is a translated filename, try that first.
+	// Note that we set the default type to io-error, so that if we didn't try
+	// the local filename first, we will load the file from the canonical filename.
+	Thumbnail thumbnail { QImage(), MEDIATYPE_IO_ERROR };
 	if (localFilename != filename)
-		std::tie(thumb, stillLoading) = fetchImage(localFilename, filename, tryDownload);
+		thumbnail = fetchImage(localFilename, filename, tryDownload);
 
-	// Note that the translated filename should never be a remote file and therefore checking for
-	// stillLoading is currently not necessary. But in the future, we might support such a use case
-	// (e.g. images stored in the cloud).
-	if (thumb.isNull() && !stillLoading)
-		std::tie(thumb, stillLoading) = fetchImage(filename, filename, tryDownload);
+	// If fetching from the local filename failed (or we didn't even try),
+	// use the canonical filename. This might for example happen if we downloaded
+	// a file, but for some reason lost the cached file.
+	if (thumbnail.type == MEDIATYPE_IO_ERROR)
+		thumbnail = fetchImage(filename, filename, tryDownload);
 
-	if (thumb.isNull() && !stillLoading)
+	if (thumbnail.type == MEDIATYPE_IO_ERROR)
 		qInfo() << "Error loading image" << filename << "[local:" << localFilename << "]";
-	return { thumb, stillLoading };
+	return thumbnail;
 }
 
 static QImage renderIcon(const char *id, int size)
@@ -130,7 +159,9 @@ static QImage renderIcon(const char *id, int size)
 }
 
 Thumbnailer::Thumbnailer() : failImage(renderIcon(":filter-close", maxThumbnailSize())), // TODO: Don't misuse filter close icon
-			     dummyImage(renderIcon(":camera-icon", maxThumbnailSize()))
+			     dummyImage(renderIcon(":camera-icon", maxThumbnailSize())),
+			     videoImage(renderIcon(":video-icon", maxThumbnailSize())),
+			     unknownImage(renderIcon(":unknown-icon", maxThumbnailSize()))
 {
 	// Currently, we only process one image at a time. Stefan Fuchs reported problems when
 	// calculating multiple thumbnails at once and this hopefully helps.
@@ -145,11 +176,11 @@ Thumbnailer *Thumbnailer::instance()
 	return &self;
 }
 
-static QImage getThumbnailFromCache(const QString &picture_filename)
+Thumbnailer::Thumbnail Thumbnailer::getThumbnailFromCache(const QString &picture_filename)
 {
 	QString filename = thumbnailFileName(picture_filename);
 	if (filename.isEmpty())
-		return QImage();
+		return { QImage(), MEDIATYPE_UNKNOWN };
 	QFile file(filename);
 
 	if (prefs.auto_recalculate_thumbnails) {
@@ -163,27 +194,34 @@ static QImage getThumbnailFromCache(const QString &picture_filename)
 			if (pictureTime.isValid() && thumbnailTime.isValid() && thumbnailTime < pictureTime) {
 				// Both files exist, have valid timestamps and thumbnail was calculated before picture.
 				// Return an empty thumbnail to signal recalculation of the thumbnail
-				return QImage();
+				return { QImage(), MEDIATYPE_UNKNOWN };
 			}
 		}
 	}
 
 	if (!file.open(QIODevice::ReadOnly))
-		return QImage();
+		return { QImage(), MEDIATYPE_UNKNOWN };
 	QDataStream stream(&file);
 
 	// Each thumbnail file is composed of a media-type and an image file.
-	// Currently, the type is ignored. This will be used to mark videos.
 	quint32 type;
 	QImage res;
 	stream >> type;
 	stream >> res;
-	return res;
+
+	// Thumbnails of videos currently not supported - replace by dummy
+	// TODO: Perhaps extract thumbnails
+	if (type == MEDIATYPE_VIDEO)
+		res = videoImage;
+	else if (type == MEDIATYPE_UNKNOWN)
+		res = unknownImage;
+
+	return { res, (mediatype_t)type };
 }
 
-static void addThumbnailToCache(const QImage &thumbnail, const QString &picture_filename)
+void Thumbnailer::addThumbnailToCache(const Thumbnail &thumbnail, const QString &picture_filename)
 {
-	if (thumbnail.isNull())
+	if (thumbnail.img.isNull())
 		return;
 
 	QString filename = thumbnailFileName(picture_filename);
@@ -192,58 +230,54 @@ static void addThumbnailToCache(const QImage &thumbnail, const QString &picture_
 		return;
 	QDataStream stream(&file);
 
-	// For format of the file, see comments in getThumnailForCache
-	quint32 type = MEDIATYPE_PICTURE;
-	stream << type;
-	stream << thumbnail;
+	stream << (quint32)thumbnail.type;
+	if (thumbnail.type == MEDIATYPE_PICTURE) // TODO: Perhaps also support caching of video thumbnails
+		stream << thumbnail.img;
 	file.commit();
 }
 
 void Thumbnailer::recalculate(QString filename)
 {
-	auto res = getHashedImage(filename, true);
+	Thumbnail thumbnail = getHashedImage(filename, true);
 
 	// If we couldn't load the image from disk -> leave old thumbnail.
 	// The case "load from web" is a bit inconsistent: it will call into processItem() later
 	// and therefore a "broken" image symbol may be shown.
-	if (res.second || res.first.isNull())
+	if (thumbnail.type == MEDIATYPE_STILL_LOADING || thumbnail.type == MEDIATYPE_IO_ERROR)
 		return;
-	QImage thumbnail = res.first;
 	addThumbnailToCache(thumbnail, filename);
 
 	QMutexLocker l(&lock);
-	emit thumbnailChanged(filename, thumbnail);
+	emit thumbnailChanged(filename, thumbnail.img);
 	workingOn.remove(filename);
 }
 
 void Thumbnailer::processItem(QString filename, bool tryDownload)
 {
-	QImage thumbnail = getThumbnailFromCache(filename);
+	Thumbnail thumbnail = getThumbnailFromCache(filename);
 
-	if (thumbnail.isNull()) {
-		auto res = getHashedImage(filename, tryDownload);
-		if (res.second)
+	if (thumbnail.img.isNull()) {
+		thumbnail = getHashedImage(filename, tryDownload);
+		if (thumbnail.type == MEDIATYPE_STILL_LOADING)
 			return;
-		thumbnail = res.first;
 
-		if (thumbnail.isNull()) {
-			thumbnail = failImage;
+		if (thumbnail.img.isNull()) {
+			thumbnail.img = failImage;
 		} else {
 			int size = maxThumbnailSize();
-			thumbnail = thumbnail.scaled(size, size, Qt::KeepAspectRatio);
+			thumbnail.img = thumbnail.img.scaled(size, size, Qt::KeepAspectRatio);
 			addThumbnailToCache(thumbnail, filename);
 		}
 	}
 
 	QMutexLocker l(&lock);
-	emit thumbnailChanged(filename, thumbnail);
+	emit thumbnailChanged(filename, thumbnail.img);
 	workingOn.remove(filename);
 }
 
 void Thumbnailer::imageDownloaded(QString filename)
 {
-	// Image was downloaded and the filename connected with a hash.
-	// Try thumbnailing again.
+	// Image was downloaded -> try thumbnailing again.
 	QMutexLocker l(&lock);
 	workingOn[filename] = QtConcurrent::run(&pool, [this, filename]() { processItem(filename, false); });
 }
@@ -255,12 +289,11 @@ void Thumbnailer::imageDownloadFailed(QString filename)
 	workingOn.remove(filename);
 }
 
-QImage Thumbnailer::fetchThumbnail(PictureEntry &entry)
+QImage Thumbnailer::fetchThumbnail(const QString &filename)
 {
 	QMutexLocker l(&lock);
 
 	// We are not currently fetching this thumbnail - add it to the list.
-	const QString &filename = entry.filename;
 	if (!workingOn.contains(filename)) {
 		workingOn.insert(filename,
 				 QtConcurrent::run(&pool, [this, filename]() { processItem(filename, true); }));
