@@ -4,7 +4,9 @@
 #pragma clang diagnostic ignored "-Wmissing-field-initializers"
 #endif
 
+#include "ssrf.h"
 #include "dive.h"
+#include "subsurface-string.h"
 #include "parse.h"
 #include "divelist.h"
 #include "device.h"
@@ -13,9 +15,9 @@
 
 extern int shearwater_cylinders(void *handle, int columns, char **data, char **column)
 {
-	(void) handle;
-	(void) columns;
-	(void) column;
+	UNUSED(handle);
+	UNUSED(columns);
+	UNUSED(column);
 
 	int o2 = lrint(strtod_flags(data[0], NULL, 0) * 1000);
 	int he = lrint(strtod_flags(data[1], NULL, 0) * 1000);
@@ -35,9 +37,9 @@ extern int shearwater_cylinders(void *handle, int columns, char **data, char **c
 
 extern int shearwater_changes(void *handle, int columns, char **data, char **column)
 {
-	(void) handle;
-	(void) columns;
-	(void) column;
+	UNUSED(handle);
+	UNUSED(columns);
+	UNUSED(column);
 
 	if (columns != 3) {
 		return 1;
@@ -77,9 +79,10 @@ extern int shearwater_changes(void *handle, int columns, char **data, char **col
 
 extern int shearwater_profile_sample(void *handle, int columns, char **data, char **column)
 {
-	(void) handle;
-	(void) columns;
-	(void) column;
+	UNUSED(handle);
+	UNUSED(columns);
+	UNUSED(column);
+	int d6, d7;
 
 	sample_start();
 	if (data[0])
@@ -95,8 +98,25 @@ extern int shearwater_profile_sample(void *handle, int columns, char **data, cha
 		cur_sample->ndl.seconds = atoi(data[4]) * 60;
 	if (data[5])
 		cur_sample->cns = atoi(data[5]);
-	if (data[6])
-		cur_sample->stopdepth.mm = metric ? atoi(data[6]) * 1000 : feet_to_mm(atoi(data[6]));
+	if (data[6]) {
+		d6 = atoi(data[6]);
+		if (d6 > 0) {
+			cur_sample->stopdepth.mm = metric ? d6 * 1000 : feet_to_mm(d6);
+			cur_sample->in_deco = 1;
+		} else if (data[7]) {
+			d7 = atoi(data[7]);
+			if (d7 > 0) {
+				cur_sample->stopdepth.mm = metric ? d7 * 1000 : feet_to_mm(d7);
+				if (data[8])
+					cur_sample->stoptime.seconds = atoi(data[8]) * 60;
+				cur_sample->in_deco = 1;
+			} else {
+				cur_sample->in_deco = 0;
+			}
+		} else {
+			cur_sample->in_deco = 0;
+		}
+	}
 
 	/* We don't actually have data[3], but it should appear in the
 	 * SQL query at some point.
@@ -110,9 +130,10 @@ extern int shearwater_profile_sample(void *handle, int columns, char **data, cha
 
 extern int shearwater_ai_profile_sample(void *handle, int columns, char **data, char **column)
 {
-	(void) handle;
-	(void) columns;
-	(void) column;
+	UNUSED(handle);
+	UNUSED(columns);
+	UNUSED(column);
+	int d6, d9;
 
 	sample_start();
 	if (data[0])
@@ -128,8 +149,25 @@ extern int shearwater_ai_profile_sample(void *handle, int columns, char **data,
 		cur_sample->ndl.seconds = atoi(data[4]) * 60;
 	if (data[5])
 		cur_sample->cns = atoi(data[5]);
-	if (data[6])
-		cur_sample->stopdepth.mm = metric ? atoi(data[6]) * 1000 : feet_to_mm(atoi(data[6]));
+	if (data[6]) {
+		d6 = atoi(data[6]);
+		if (d6 > 0) {
+			cur_sample->stopdepth.mm = metric ? d6 * 1000 : feet_to_mm(d6);
+			cur_sample->in_deco = 1;
+		} else if (data[9]) {
+			d9 = atoi(data[9]);
+			if (d9 > 0) {
+				cur_sample->stopdepth.mm = metric ? d9 * 1000 : feet_to_mm(d9);
+				if (data[10])
+					cur_sample->stoptime.seconds = atoi(data[10]) * 60;
+				cur_sample->in_deco = 1;
+			} else {
+				cur_sample->in_deco = 0;
+			}
+		} else {
+			cur_sample->in_deco = 0;
+		}
+	}
 
 	/* Weird unit conversion but seems to produce correct results.
 	 * Also missing values seems to be reported as a 4092 (564 bar) */
@@ -145,9 +183,9 @@ extern int shearwater_ai_profile_sample(void *handle, int columns, char **data,
 
 extern int shearwater_mode(void *handle, int columns, char **data, char **column)
 {
-	(void) handle;
-	(void) columns;
-	(void) column;
+	UNUSED(handle);
+	UNUSED(columns);
+	UNUSED(column);
 
 	if (data[0])
 		cur_dive->dc.divemode = atoi(data[0]) == 0 ? CCR : OC;
@@ -157,14 +195,14 @@ extern int shearwater_mode(void *handle, int columns, char **data, char **column
 
 extern int shearwater_dive(void *param, int columns, char **data, char **column)
 {
-	(void) columns;
-	(void) column;
+	UNUSED(columns);
+	UNUSED(column);
 
 	int retval = 0;
 	sqlite3 *handle = (sqlite3 *)param;
 	char *err = NULL;
-	char get_profile_template[] = "select currentTime,currentDepth,waterTemp,averagePPO2,currentNdl,CNSPercent,decoCeiling from dive_log_records where diveLogId=%d";
-	char get_profile_template_ai[] = "select currentTime,currentDepth,waterTemp,averagePPO2,currentNdl,CNSPercent,decoCeiling,aiSensor0_PressurePSI,aiSensor1_PressurePSI from dive_log_records where diveLogId = %d";
+	char get_profile_template[] = "select currentTime,currentDepth,waterTemp,averagePPO2,currentNdl,CNSPercent,decoCeiling,firstStopDepth,firstStopTime from dive_log_records where diveLogId=%d";
+	char get_profile_template_ai[] = "select currentTime,currentDepth,waterTemp,averagePPO2,currentNdl,CNSPercent,decoCeiling,aiSensor0_PressurePSI,aiSensor1_PressurePSI,firstStopDepth,firstStopTime from dive_log_records where diveLogId = %d";
 	char get_cylinder_template[] = "select fractionO2,fractionHe from dive_log_records where diveLogId = %d group by fractionO2,fractionHe";
 	char get_changes_template[] = "select a.currentTime,a.fractionO2,a.fractionHe from dive_log_records as a,dive_log_records as b where (a.id - 1) = b.id and (a.fractionO2 != b.fractionO2 or a.fractionHe != b.fractionHe) and a.diveLogId=b.divelogId and a.diveLogId = %d";
 	char get_mode_template[] = "select distinct currentCircuitSetting from dive_log_records where diveLogId = %d";
@@ -277,8 +315,8 @@ extern int shearwater_dive(void *param, int columns, char **data, char **column)
 int parse_shearwater_buffer(sqlite3 *handle, const char *url, const char *buffer, int size,
 			    struct dive_table *table)
 {
-	(void) buffer;
-	(void) size;
+	UNUSED(buffer);
+	UNUSED(size);
 
 	int retval;
 	char *err = NULL;
