@@ -4,7 +4,9 @@
 #pragma clang diagnostic ignored "-Wmissing-field-initializers"
 #endif
 
+#include "ssrf.h"
 #include "dive.h"
+#include "subsurface-string.h"
 #include "parse.h"
 #include "divelist.h"
 #include "device.h"
@@ -13,9 +15,9 @@
 
 extern int dm4_events(void *handle, int columns, char **data, char **column)
 {
-	(void) handle;
-	(void) columns;
-	(void) column;
+	UNUSED(handle);
+	UNUSED(columns);
+	UNUSED(column);
 
 	event_start();
 	if (data[1])
@@ -146,9 +148,9 @@ extern int dm4_events(void *handle, int columns, char **data, char **column)
 
 extern int dm4_tags(void *handle, int columns, char **data, char **column)
 {
-	(void) handle;
-	(void) columns;
-	(void) column;
+	UNUSED(handle);
+	UNUSED(columns);
+	UNUSED(column);
 
 	if (data[0])
 		taglist_add_tag(&cur_dive->tag_list, data[0]);
@@ -158,8 +160,8 @@ extern int dm4_tags(void *handle, int columns, char **data, char **column)
 
 extern int dm4_dive(void *param, int columns, char **data, char **column)
 {
-	(void) columns;
-	(void) column;
+	UNUSED(columns);
+	UNUSED(column);
 	int i;
 	int interval, retval = 0;
 	sqlite3 *handle = (sqlite3 *)param;
@@ -288,8 +290,8 @@ extern int dm4_dive(void *param, int columns, char **data, char **column)
 int parse_dm4_buffer(sqlite3 *handle, const char *url, const char *buffer, int size,
 		     struct dive_table *table)
 {
-	(void) buffer;
-	(void) size;
+	UNUSED(buffer);
+	UNUSED(size);
 
 	int retval;
 	char *err = NULL;
@@ -311,9 +313,9 @@ int parse_dm4_buffer(sqlite3 *handle, const char *url, const char *buffer, int s
 
 extern int dm5_cylinders(void *handle, int columns, char **data, char **column)
 {
-	(void) handle;
-	(void) columns;
-	(void) column;
+	UNUSED(handle);
+	UNUSED(columns);
+	UNUSED(column);
 
 	cylinder_start();
 	if (data[7] && atoi(data[7]) > 0 && atoi(data[7]) < 350000)
@@ -339,9 +341,9 @@ extern int dm5_cylinders(void *handle, int columns, char **data, char **column)
 
 extern int dm5_gaschange(void *handle, int columns, char **data, char **column)
 {
-	(void) handle;
-	(void) columns;
-	(void) column;
+	UNUSED(handle);
+	UNUSED(columns);
+	UNUSED(column);
 
 	event_start();
 	if (data[0])
@@ -361,9 +363,10 @@ extern int dm5_gaschange(void *handle, int columns, char **data, char **column)
 
 extern int dm5_dive(void *param, int columns, char **data, char **column)
 {
-	(void) columns;
-	(void) column;
+	UNUSED(columns);
+	UNUSED(column);
 	int i;
+	int tempformat = 0;
 	int interval, retval = 0, block_size;
 	sqlite3 *handle = (sqlite3 *)param;
 	unsigned const char *sampleBlob;
@@ -425,10 +428,25 @@ extern int dm5_dive(void *param, int columns, char **data, char **column)
 		cur_dive->dc.surface_pressure.mbar = (atoi(data[14]) / 100);
 
 	interval = data[16] ? atoi(data[16]) : 0;
+
+	/*
+	 * sampleBlob[0]	version number, indicates the size of one sample
+	 *
+	 * Following ones describe single sample, bugs in interpretation of the binary blob are likely:
+	 *
+	 * sampleBlob[3]	depth
+	 * sampleBlob[7-9]	pressure
+	 * sampleBlob[11]	temperature - either full Celsius or float, might be different field for some version of DM
+	 */
+
 	sampleBlob = (unsigned const char *)data[24];
 
 	if (sampleBlob) {
 		switch (sampleBlob[0]) {
+			case 1:
+				// Log is converted from DM4 to DM5
+				block_size = 16;
+				break;
 			case 2:
 				block_size = 19;
 				break;
@@ -436,8 +454,15 @@ extern int dm5_dive(void *param, int columns, char **data, char **column)
 				block_size = 23;
 				break;
 			case 4:
+				// Temperature is stored in float
+				tempformat = 1;
 				block_size = 26;
 				break;
+			case 5:
+				// Temperature is stored in float
+				tempformat = 1;
+				block_size = 30;
+				break;
 			default:
 				block_size = 16;
 				break;
@@ -446,18 +471,24 @@ extern int dm5_dive(void *param, int columns, char **data, char **column)
 
 	for (i = 0; interval && sampleBlob && i * interval < cur_dive->duration.seconds; i++) {
 		float *depth = (float *)&sampleBlob[i * block_size + 3];
-		int32_t temp = (sampleBlob[i * block_size + 10] << 8) + sampleBlob[i * block_size + 11];
 		int32_t pressure = (sampleBlob[i * block_size + 9] << 16) + (sampleBlob[i * block_size + 8] << 8) + sampleBlob[i * block_size + 7];
 
 		sample_start();
 		cur_sample->time.seconds = i * interval;
 		cur_sample->depth.mm = lrintf(depth[0] * 1000.0f);
+
+		if (tempformat == 1) {
+			float *temp = (float *)&(sampleBlob[i * block_size + 11]);
+			cur_sample->temperature.mkelvin = C_to_mkelvin(*temp);
+		} else {
+			if ((sampleBlob[i * block_size + 11]) != 0x7F) {
+				cur_sample->temperature.mkelvin = C_to_mkelvin(sampleBlob[i * block_size + 11]);
+			}
+		}
+
 		/*
-		 * Limit temperatures and cylinder pressures to somewhat
-		 * sensible values
+		 * Limit cylinder pressures to somewhat sensible values
 		 */
-		if (temp >= -10 && temp < 50)
-			cur_sample->temperature.mkelvin = C_to_mkelvin(temp);
 		if (pressure >= 0 && pressure < 350000)
 			cur_sample->pressure[0].mbar = pressure;
 		sample_end();
@@ -521,8 +552,8 @@ extern int dm5_dive(void *param, int columns, char **data, char **column)
 int parse_dm5_buffer(sqlite3 *handle, const char *url, const char *buffer, int size,
 		     struct dive_table *table)
 {
-	(void) buffer;
-	(void) size;
+	UNUSED(buffer);
+	UNUSED(size);
 
 	int retval;
 	char *err = NULL;
