@@ -4,25 +4,33 @@
 #pragma clang diagnostic ignored "-Wmissing-field-initializers"
 #endif
 
+#include "ssrf.h"
 #include <stdio.h>
 #include <unistd.h>
 #include <inttypes.h>
 #include <string.h>
+#include <sys/types.h>
+#include <sys/stat.h>
+#include <fcntl.h>
 #include "gettext.h"
 #include "dive.h"
+#include "subsurface-string.h"
 #include "device.h"
 #include "divelist.h"
 #include "display.h"
 
 #include <libdivecomputer/version.h>
+#include <libdivecomputer/usbhid.h>
+#include <libdivecomputer/serial.h>
+#include <libdivecomputer/irda.h>
+
 #include "libdivecomputer.h"
 #include "core/version.h"
+#include "core/qthelper.h"
+#include "core/membuffer.h"
+#include "core/file.h"
+#include <QtGlobal>
 
-#if !defined(SSRF_LIBDC_VERSION) || SSRF_LIBDC_VERSION < 2
-#pragma message "Subsurface requires a reasonably current version of the Subsurface-branch"
-#pragma message "of libdivecomputer (at least version 2 of our API)."
-#pragma message "Please get it from http://github.com/Subsurface-divelog/libdc Subsurface-branch"
-#endif
 //
 // If we have an old libdivecomputer, it doesn't
 // have the new DC_TANKINFO bits, but just volume
@@ -422,7 +430,7 @@ sample_cb(dc_sample_type_t type, dc_sample_value_t value, void *userdata)
 
 static void dev_info(device_data_t *devdata, const char *fmt, ...)
 {
-	(void) devdata;
+	UNUSED(devdata);
 	static char buffer[1024];
 	va_list ap;
 
@@ -438,7 +446,7 @@ static int import_dive_number = 0;
 
 static int parse_samples(device_data_t *devdata, struct divecomputer *dc, dc_parser_t *parser)
 {
-	(void) devdata;
+	UNUSED(devdata);
 	// Parse the sample data.
 	return dc_parser_samples_foreach(parser, sample_cb, dc);
 }
@@ -542,8 +550,8 @@ static uint32_t calculate_string_hash(const char *str)
  */
 static void dc_match_serial(void *_dc, const char *model, uint32_t deviceid, const char *nickname, const char *serial, const char *firmware)
 {
-	(void)nickname;
-	(void)firmware;
+	UNUSED(nickname);
+	UNUSED(firmware);
 
 	struct divecomputer *dc = _dc;
 
@@ -618,9 +626,9 @@ static dc_status_t libdc_header_parser(dc_parser_t *parser, device_data_t *devda
 	}
 
 	// Parse the divetime.
-	const char *date_string = get_dive_date_c_string(dive->when);
+	char *date_string = get_dive_date_c_string(dive->when);
 	dev_info(devdata, translate("gettextFromC", "Dive %d: %s"), import_dive_number, date_string);
-	free((void *)date_string);
+	free(date_string);
 
 	unsigned int divetime = 0;
 	rc = dc_parser_get_field(parser, DC_FIELD_DIVETIME, 0, &divetime);
@@ -786,6 +794,16 @@ static int dive_cb(const unsigned char *data, unsigned int size,
 	dive->dc.model = strdup(devdata->model);
 	dive->dc.diveid = calculate_diveid(fingerprint, fsize);
 
+	/* Should we add it to the cached fingerprint file? */
+	if (fingerprint && fsize && !devdata->fingerprint) {
+		devdata->fingerprint = calloc(fsize, 1);
+		if (devdata->fingerprint) {
+			devdata->fsize = fsize;
+			devdata->fdiveid = dive->dc.diveid;
+			memcpy(devdata->fingerprint, fingerprint, fsize);
+		}
+	}
+
 	// Parse the dive's header data
 	rc = libdc_header_parser (parser, devdata, dive);
 	if (rc != DC_STATUS_SUCCESS) {
@@ -802,9 +820,9 @@ static int dive_cb(const unsigned char *data, unsigned int size,
 
 	/* If we already saw this dive, abort. */
 	if (!devdata->force_download && find_dive(&dive->dc)) {
-		const char *date_string = get_dive_date_c_string(dive->when);
+		char *date_string = get_dive_date_c_string(dive->when);
 		dev_info(devdata, translate("gettextFromC", "Already downloaded dive at %s"), date_string);
-		free((void *)date_string);
+		free(date_string);
 		goto error_exit;
 	}
 
@@ -925,10 +943,125 @@ static unsigned int fixup_suunto_versions(device_data_t *devdata, const dc_event
 
 	return serial;
 }
+#ifndef O_BINARY
+  #define O_BINARY 0
+#endif
+static void do_save_fingerprint(device_data_t *devdata, const char *tmp, const char *final)
+{
+	int fd, written = -1;
+
+	fd = subsurface_open(tmp, O_WRONLY | O_BINARY | O_CREAT | O_TRUNC, 0666);
+	if (fd < 0)
+		return;
+
+	/* The fingerprint itself.. */
+	written = write(fd, devdata->fingerprint, devdata->fsize);
+
+	/* ..followed by the dive ID of the fingerprinted dive */
+	if (write(fd, &devdata->fdiveid, 4) != 4)
+		written = -1;
+
+	/* I'd like to do fsync() here too, but does Windows support it? */
+	if (close(fd) < 0)
+		written = -1;
+
+	if (written == devdata->fsize) {
+		if (!subsurface_rename(tmp, final))
+			return;
+	}
+	unlink(tmp);
+}
+
+/*
+ * Save the fingerprint after a successful download
+ */
+static void save_fingerprint(device_data_t *devdata)
+{
+	char *dir, *tmp, *final;
+
+	if (!devdata->fingerprint)
+		return;
+
+	dir = format_string("%s/fingerprints", system_default_directory());
+	subsurface_mkdir(dir);
+	tmp = format_string("%s/%04x.tmp", dir, devdata->deviceid);
+	final = format_string("%s/%04x", dir, devdata->deviceid);
+	free(dir);
+
+	do_save_fingerprint(devdata, tmp, final);
+	free(tmp);
+	free(final);
+	free(devdata->fingerprint);
+	devdata->fingerprint = NULL;
+}
+
+static int has_dive(unsigned int deviceid, unsigned int diveid)
+{
+	int i;
+	struct dive *dive;
+
+	for_each_dive (i, dive) {
+		struct divecomputer *dc;
+
+		for_each_dc (dive, dc) {
+			if (dc->deviceid != deviceid)
+				continue;
+			if (dc->diveid != diveid)
+				continue;
+			return 1;
+		}
+	}
+	return 0;
+}
+
+/*
+ * The fingerprint cache files contain the actual libdivecomputer
+ * fingerprint, followed by 4 bytes of diveid data. Before we use
+ * the fingerprint data, verify that we actually do have that
+ * fingerprinted dive.
+ */
+static void verify_fingerprint(dc_device_t *device, device_data_t *devdata, const unsigned char *buffer, size_t size)
+{
+	unsigned int diveid, deviceid;
+
+	if (size <= 4)
+		return;
+	size -= 4;
+
+	/* Get the dive ID from the end of the fingerprint cache file.. */
+	memcpy(&diveid, buffer + size, 4);
+	/* .. and the device ID from the device data */
+	deviceid = devdata->deviceid;
+
+	/* Only use it if we *have* that dive! */
+	if (has_dive(deviceid, diveid))
+		dc_device_set_fingerprint(device, buffer, size);
+}
+
+/*
+ * Look up the fingerprint from the fingerprint caches, and
+ * give it to libdivecomputer to avoid downloading already
+ * downloaded dives.
+ */
+static void lookup_fingerprint(dc_device_t *device, device_data_t *devdata)
+{
+	char *cachename;
+	struct memblock mem;
+
+	if (devdata->force_download)
+		return;
+	cachename = format_string("%s/fingerprints/%04x",
+		system_default_directory(), devdata->deviceid);
+	if (readfile(cachename, &mem) > 0) {
+		verify_fingerprint(device, devdata, mem.buffer, mem.size);
+		free(mem.buffer);
+	}
+	free(cachename);
+}
 
 static void event_cb(dc_device_t *device, dc_event_type_t event, const void *data, void *userdata)
 {
-	(void) device;
+	UNUSED(device);
 	const dc_event_progress_t *progress = data;
 	const dc_event_devinfo_t *devinfo = data;
 	const dc_event_clock_t *clock = data;
@@ -965,6 +1098,7 @@ static void event_cb(dc_device_t *device, dc_event_type_t event, const void *dat
 				devinfo->firmware, devinfo->firmware,
 				devinfo->serial, devinfo->serial);
 		}
+
 		/*
 		 * libdivecomputer doesn't give serial numbers in the proper string form,
 		 * so we have to see if we can do some vendor-specific munging.
@@ -978,6 +1112,9 @@ static void event_cb(dc_device_t *device, dc_event_type_t event, const void *dat
 		 * DC_FIELD_STRING interface instead */
 		devdata->libdc_serial = devinfo->serial;
 		devdata->libdc_firmware = devinfo->firmware;
+
+		lookup_fingerprint(device, devdata);
+
 		break;
 	case DC_EVENT_CLOCK:
 		dev_info(devdata, translate("gettextFromC", "Event: systime=%" PRId64 ", devtime=%u\n"),
@@ -1004,7 +1141,7 @@ int import_thread_cancelled;
 
 static int cancel_cb(void *userdata)
 {
-	(void) userdata;
+	UNUSED(userdata);
 	return import_thread_cancelled;
 }
 
@@ -1054,7 +1191,7 @@ static const char *do_device_import(device_data_t *data)
 
 void logfunc(dc_context_t *context, dc_loglevel_t loglevel, const char *file, unsigned int line, const char *function, const char *msg, void *userdata)
 {
-	(void) context;
+	UNUSED(context);
 	const char *loglevels[] = { "NONE", "ERROR", "WARNING", "INFO", "DEBUG", "ALL" };
 
 	FILE *fp = (FILE *)userdata;
@@ -1066,6 +1203,148 @@ void logfunc(dc_context_t *context, dc_loglevel_t loglevel, const char *file, un
 	}
 }
 
+char *transport_string[] = {
+	"SERIAL",
+	"USB",
+	"USBHID",
+	"IRDA",
+	"BT",
+	"BLE"
+};
+
+/*
+ * Get the transports supported by us (as opposed to
+ * the list of transports supported by a particular
+ * dive computer).
+ *
+ * This could have various platform rules too..
+ */
+unsigned int get_supported_transports(device_data_t *data)
+{
+#if defined(Q_OS_IOS)
+	// BLE only - don't bother with being clever.
+	return DC_TRANSPORT_BLE;
+#endif
+	// start out with the list of transports that libdivecomputer claims to support
+	// dc_context_get_transports ignores its context argument...
+	unsigned int supported = dc_context_get_transports(NULL);
+
+	// then add the ones that we have our own implementations for
+#if defined(BT_SUPPORT)
+	supported |= DC_TRANSPORT_BLUETOOTH;
+#endif
+#if defined(BLE_SUPPORT)
+	supported |= DC_TRANSPORT_BLE;
+#endif
+
+	if (data) {
+		/*
+		 * If we have device data available, we can refine this:
+		 * We don't support BT or BLE unless bluetooth_mode was set,
+		 * and if it was we won't try any of the other transports.
+		 */
+		if (data->bluetooth_mode) {
+			supported &= (DC_TRANSPORT_BLUETOOTH | DC_TRANSPORT_BLE);
+			if (!strncmp(data->devname, "LE:", 3))
+				supported &= DC_TRANSPORT_BLE;
+		} else {
+			supported &= ~(DC_TRANSPORT_BLUETOOTH | DC_TRANSPORT_BLE);
+		}
+	}
+	return supported;
+}
+
+dc_status_t divecomputer_device_open(device_data_t *data)
+{
+	dc_status_t rc;
+	dc_descriptor_t *descriptor = data->descriptor;
+	dc_context_t *context = data->context;
+	unsigned int transports, supported;
+
+	transports = dc_descriptor_get_transports(descriptor);
+	supported = get_supported_transports(data);
+
+	transports &= supported;
+	if (!transports) {
+		report_error("Dive computer transport not supported");
+		return DC_STATUS_UNSUPPORTED;
+	}
+
+#ifdef BT_SUPPORT
+	if (transports & DC_TRANSPORT_BLUETOOTH) {
+		rc = rfcomm_stream_open(&data->iostream, context, data->devname);
+		if (rc == DC_STATUS_SUCCESS)
+			return rc;
+	}
+#endif
+
+#ifdef BLE_SUPPORT
+	if (transports & DC_TRANSPORT_BLE) {
+		rc = ble_packet_open(&data->iostream, context, data->devname, data);
+		if (rc == DC_STATUS_SUCCESS)
+			return rc;
+	}
+#endif
+
+	if (transports & DC_TRANSPORT_USBHID) {
+		// Discover the usbhid device.
+		dc_iterator_t *iterator = NULL;
+		dc_usbhid_device_t *device = NULL;
+		dc_usbhid_iterator_new (&iterator, context, descriptor);
+		while (dc_iterator_next (iterator, &device) == DC_STATUS_SUCCESS)
+			break;
+		dc_iterator_free (iterator);
+
+		if (device) {
+			rc = dc_usbhid_open(&data->iostream, context, device);
+			dc_usbhid_device_free(device);
+			if (rc == DC_STATUS_SUCCESS)
+				return rc;
+		}
+	}
+
+	/* The dive computer backend does this all internally */
+	if (transports & DC_TRANSPORT_USB)
+		return DC_STATUS_SUCCESS;
+
+	if (transports & DC_TRANSPORT_SERIAL) {
+#ifdef SERIAL_FTDI
+		if (!strcmp(data->devname, "ftdi")) {
+			rc = ftdi_open(&data->iostream, context);
+			if (rc == DC_STATUS_SUCCESS)
+				return rc;
+		}
+#endif
+		rc = dc_serial_open(&data->iostream, context, data->devname);
+		if (rc == DC_STATUS_SUCCESS)
+			return rc;
+
+	}
+
+	if (transports & DC_TRANSPORT_IRDA) {
+		unsigned int address = 0;
+
+		dc_iterator_t *iterator = NULL;
+		dc_irda_device_t *device = NULL;
+		dc_irda_iterator_new (&iterator, context, descriptor);
+		while (dc_iterator_next (iterator, &device) == DC_STATUS_SUCCESS) {
+			address = dc_irda_device_get_address (device);
+			dc_irda_device_free (device);
+			break;
+		}
+		dc_iterator_free (iterator);
+
+		if (!address)
+			address = strtoul(data->devname, NULL, 0);
+
+		rc = dc_irda_open(&data->iostream, context, address, 1);
+		if (rc == DC_STATUS_SUCCESS)
+			return rc;
+	}
+
+	return DC_STATUS_UNSUPPORTED;
+}
+
 const char *do_libdivecomputer_import(device_data_t *data)
 {
 	dc_status_t rc;
@@ -1076,6 +1355,9 @@ const char *do_libdivecomputer_import(device_data_t *data)
 	first_temp_is_air = 0;
 	data->device = NULL;
 	data->context = NULL;
+	data->iostream = NULL;
+	data->fingerprint = NULL;
+	data->fsize = 0;
 
 	if (data->libdc_log && logfile_name)
 		fp = subsurface_fopen(logfile_name, "w");
@@ -1095,30 +1377,19 @@ const char *do_libdivecomputer_import(device_data_t *data)
 
 	err = translate("gettextFromC", "Unable to open %s %s (%s)");
 
-#if defined(SSRF_CUSTOM_IO)
-	if (data->bluetooth_mode) {
-#if defined(BT_SUPPORT) && defined(SSRF_CUSTOM_IO)
-		rc = dc_context_set_custom_io(data->context, get_qt_serial_ops(), data);
-#endif
-#ifdef SERIAL_FTDI
-	} else if (!strcmp(data->devname, "ftdi")) {
-		rc = dc_context_set_custom_io(data->context, &serial_ftdi_ops, data);
-		INFO(0, "setting up ftdi ops");
-#else
-		INFO(0, "FTDI disabled");
-#endif
-	}
+	rc = divecomputer_device_open(data);
 
 	if (rc != DC_STATUS_SUCCESS) {
 		report_error(errmsg(rc));
 	} else {
-#else
-	{
-#endif
-		rc = dc_device_open(&data->device, data->context, data->descriptor, data->devname);
-		INFO(0, "dc_deveice_open error value of %d", rc);
+		rc = dc_device_open(&data->device, data->context, data->descriptor, data->iostream);
+		INFO(0, "dc_device_open error value of %d", rc);
 		if (rc != DC_STATUS_SUCCESS && subsurface_access(data->devname, R_OK | W_OK) != 0)
+#if defined(SUBSURFACE_MOBILE)
+			err = translate("gettextFromC", "Error opening the device %s %s (%s).\nIn most cases, in order to debug this issue, it is useful to send the developers the log files. You can copy them to the clipboard in the About dialog.");
+#else
 			err = translate("gettextFromC", "Error opening the device %s %s (%s).\nIn most cases, in order to debug this issue, a libdivecomputer logfile will be useful.\nYou can create this logfile by selecting the corresponding checkbox in the download dialog.");
+#endif
 	}
 
 	if (rc == DC_STATUS_SUCCESS) {
@@ -1126,6 +1397,8 @@ const char *do_libdivecomputer_import(device_data_t *data)
 		/* TODO: Show the logfile to the user on error. */
 		dc_device_close(data->device);
 		data->device = NULL;
+		dc_iostream_close(data->iostream);
+		data->iostream = NULL;
 		if (!downloadTable.nr)
 			dev_info(data, translate("gettextFromC", "No new dives downloaded from dive computer"));
 	}
@@ -1137,6 +1410,15 @@ const char *do_libdivecomputer_import(device_data_t *data)
 		fclose(fp);
 	}
 
+	/*
+	 * Note that we save the fingerprint unconditionally.
+	 * This is ok because we only have fingerprint data if
+	 * we got a dive header, and because we will use the
+	 * dive id to verify that we actually have the dive
+	 * it refers to before we use the fingerprint data.
+	 */
+	save_fingerprint(data);
+
 	return err;
 }
 
