@@ -955,11 +955,12 @@ static void parse_picture_gps(char *line, struct membuffer *str, void *_pic)
 
 static void parse_picture_hash(char *line, struct membuffer *str, void *_pic)
 {
+	// we no longer use hashes to identify pictures, but we shouldn't
+	// remove this parser or otherwise users get an ugly red warning when
+	// opening old git repos
 	UNUSED(line);
-	struct picture *pic = _pic;
-	char *hash = get_utf8(str);
-	register_hash(pic->filename, get_utf8(str));
-	free(hash);
+	UNUSED(_pic);
+	UNUSED(str);
 }
 
 /* These need to be sorted! */
