@@ -1,3 +1,4 @@
+#include "ssrf.h"
 #include <stdio.h>
 #include <assert.h>
 #include <stdarg.h>
@@ -7,6 +8,7 @@
 #include <libdivecomputer/parser.h>
 
 #include "dive.h"
+#include "subsurface-string.h"
 #include "parse.h"
 #include "divelist.h"
 #include "device.h"
@@ -194,7 +196,7 @@ bool is_dive(void)
 void reset_dc_info(struct divecomputer *dc)
 {
 	/* WARN: reset dc info does't touch the dc? */
-	(void) dc;
+	UNUSED(dc);
 	lastcylinderindex = 0;
 }
 
