@@ -5,11 +5,13 @@
  *
  * (c) Dirk Hohndel 2013
  */
+#include "ssrf.h"
 #include <assert.h>
 #include <unistd.h>
 #include <ctype.h>
 #include <string.h>
 #include "dive.h"
+#include "subsurface-string.h"
 #include "deco.h"
 #include "divelist.h"
 #include "planner.h"
@@ -114,13 +116,13 @@ int get_gasidx(struct dive *dive, struct gasmix *mix)
 	return find_best_gasmix_match(mix, dive->cylinder, 0);
 }
 
-void interpolate_transition(struct deco_state *ds, struct dive *dive, duration_t t0, duration_t t1, depth_t d0, depth_t d1, const struct gasmix *gasmix, o2pressure_t po2)
+void interpolate_transition(struct deco_state *ds, struct dive *dive, duration_t t0, duration_t t1, depth_t d0, depth_t d1, const struct gasmix *gasmix, o2pressure_t po2, enum divemode_t divemode)
 {
 	int32_t j;
 
 	for (j = t0.seconds; j < t1.seconds; j++) {
 		int depth = interpolate(d0.mm, d1.mm, j - t0.seconds, t1.seconds - t0.seconds);
-		add_segment(ds, depth_to_bar(depth, dive), gasmix, 1, po2.mbar, dive, prefs.bottomsac);
+		add_segment(ds, depth_to_bar(depth, dive), gasmix, 1, po2.mbar, divemode, prefs.bottomsac);
 	}
 	if (d1.mm > d0.mm)
 		calc_crushing_pressure(ds, depth_to_bar(d1.mm, &displayed_dive));
@@ -150,6 +152,9 @@ int tissue_at_end(struct deco_state *ds, struct dive *dive, struct deco_state **
 		return 0;
 	psample = sample = dc->sample;
 
+	struct event *evdm = NULL;
+	enum divemode_t divemode = UNDEF_COMP_TYPE;
+
 	for (i = 0; i < dc->samples; i++, sample++) {
 		o2pressure_t setpoint;
 
@@ -186,7 +191,8 @@ int tissue_at_end(struct deco_state *ds, struct dive *dive, struct deco_state **
 				ds->max_bottom_ceiling_pressure.mbar = ceiling_pressure.mbar;
 		}
 
-		interpolate_transition(ds, dive, t0, t1, lastdepth, sample->depth, &gas, setpoint);
+		divemode = get_current_divemode(&dive->dc, t0.seconds + 1, &evdm, &divemode);
+		interpolate_transition(ds, dive, t0, t1, lastdepth, sample->depth, &gas, setpoint, divemode);
 		psample = sample;
 		t0 = t1;
 	}
@@ -203,7 +209,7 @@ void fill_default_cylinder(cylinder_t *cyl)
 
 	if (!cyl_name)
 		return;
-	while (ti->name != NULL) {
+	while (ti->name != NULL && ti < tank_info + MAX_TANK_INFO) {
 		if (strcmp(ti->name, cyl_name) == 0)
 			break;
 		ti++;
@@ -226,14 +232,14 @@ void fill_default_cylinder(cylinder_t *cyl)
 
 /* calculate the new end pressure of the cylinder, based on its current end pressure and the
  * latest segment. */
-static void update_cylinder_pressure(struct dive *d, int old_depth, int new_depth, int duration, int sac, cylinder_t *cyl, bool in_deco)
+static void update_cylinder_pressure(struct dive *d, int old_depth, int new_depth, int duration, int sac, cylinder_t *cyl, bool in_deco, enum divemode_t divemode)
 {
 	volume_t gas_used;
 	pressure_t delta_p;
 	depth_t mean_depth;
 	int factor = 1000;
 
-	if (d->dc.divemode == PSCR)
+	if (divemode == PSCR)
 		factor = prefs.pscr_ratio;
 
 	if (!cyl)
@@ -262,7 +268,7 @@ static void create_dive_from_plan(struct diveplan *diveplan, struct dive *dive,
 	int lasttime = 0, last_manual_point = 0;
 	depth_t lastdepth = {.mm = 0};
 	int lastcylid;
-	enum dive_comp_type type = dive->dc.divemode;
+	enum divemode_t type = dive->dc.divemode;
 
 	if (!diveplan || !diveplan->dp)
 		return;
@@ -278,10 +284,7 @@ static void create_dive_from_plan(struct diveplan *diveplan, struct dive *dive,
 	dc->when = dive->when = diveplan->when;
 	dc->surface_pressure.mbar = diveplan->surface_pressure;
 	dc->salinity = diveplan->salinity;
-	free(dc->sample);
-	dc->sample = NULL;
-	dc->samples = 0;
-	dc->alloc_samples = 0;
+	free_samples(dc);
 	while ((ev = dc->events)) {
 		dc->events = dc->events->next;
 		free(ev);
@@ -300,8 +303,6 @@ static void create_dive_from_plan(struct diveplan *diveplan, struct dive *dive,
 	lastcylid = 0;
 	while (dp) {
 		int po2 = dp->setpoint;
-		if (dp->setpoint)
-			type = CCR;
 		int time = dp->time;
 		depth_t depth = dp->depth;
 
@@ -317,7 +318,8 @@ static void create_dive_from_plan(struct diveplan *diveplan, struct dive *dive,
 			/* this is a bad idea - we should get a different SAMPLE_EVENT type
 			 * reserved for this in libdivecomputer... overloading SMAPLE_EVENT_PO2
 			 * with a different meaning will only cause confusion elsewhere in the code */
-			add_event(dc, lasttime, SAMPLE_EVENT_PO2, 0, po2, QT_TRANSLATE_NOOP("gettextFromC", "SP change"));
+			if (dp->divemode == type)
+				add_event(dc, lasttime, SAMPLE_EVENT_PO2, 0, po2, QT_TRANSLATE_NOOP("gettextFromC", "SP change"));
 			oldpo2 = po2;
 		}
 
@@ -335,6 +337,11 @@ static void create_dive_from_plan(struct diveplan *diveplan, struct dive *dive,
 			finish_sample(dc);
 			lastcylid = dp->cylinderid;
 		}
+		if (dp->divemode != type) {
+			type = dp->divemode;
+			add_event(dc, lasttime, 8, 0, type, "modechange");
+		}
+
 		/* Create sample */
 		sample = prepare_sample(dc);
 		/* set po2 at beginning of this segment */
@@ -348,7 +355,7 @@ static void create_dive_from_plan(struct diveplan *diveplan, struct dive *dive,
 		sample->sac.mliter = dp->entered ? prefs.bottomsac : prefs.decosac;
 		if (track_gas && !sample[-1].setpoint.mbar) {    /* Don't track gas usage for CCR legs of dive */
 			update_cylinder_pressure(dive, sample[-1].depth.mm, depth.mm, time - sample[-1].time.seconds,
-					dp->entered ? diveplan->bottomsac : diveplan->decosac, cyl, !dp->entered);
+					dp->entered ? diveplan->bottomsac : diveplan->decosac, cyl, !dp->entered, type);
 			if (cyl->type.workingpressure.mbar)
 				sample->pressure[0].mbar = cyl->end.mbar;
 		}
@@ -357,7 +364,6 @@ static void create_dive_from_plan(struct diveplan *diveplan, struct dive *dive,
 	}
 	dive->dc.last_manual_time.seconds = last_manual_point;
 
-	dc->divemode = type;
 #if DEBUG_PLAN & 32
 	save_dive(stdout, &displayed_dive);
 #endif
@@ -408,10 +414,11 @@ void add_to_end_of_diveplan(struct diveplan *diveplan, struct divedatapoint *dp)
 		dp->time += lasttime;
 }
 
-struct divedatapoint *plan_add_segment(struct diveplan *diveplan, int duration, int depth, int cylinderid, int po2, bool entered)
+struct divedatapoint *plan_add_segment(struct diveplan *diveplan, int duration, int depth, int cylinderid, int po2, bool entered, enum divemode_t divemode)
 {
-	struct divedatapoint *dp = create_dp(duration, depth, cylinderid, po2);
+	struct divedatapoint *dp = create_dp(duration, depth, cylinderid, divemode == CCR ? po2 : 0);
 	dp->entered = entered;
+	dp->divemode = divemode;
 	add_to_end_of_diveplan(diveplan, dp);
 	return dp;
 }
@@ -523,7 +530,7 @@ static int *sort_stops(int *dstops, int dnr, struct gaschanges *gstops, int gnr)
 
 int ascent_velocity(int depth, int avg_depth, int bottom_time)
 {
-	(void) bottom_time;
+	UNUSED(bottom_time);
 	/* We need to make this configurable */
 
 	/* As an example (and possibly reasonable default) this is the Tech 1 provedure according
@@ -543,15 +550,15 @@ int ascent_velocity(int depth, int avg_depth, int bottom_time)
 	}
 }
 
-void track_ascent_gas(int depth, cylinder_t *cylinder, int avg_depth, int bottom_time, bool safety_stop)
+void track_ascent_gas(int depth, cylinder_t *cylinder, int avg_depth, int bottom_time, bool safety_stop, enum divemode_t divemode)
 {
 	while (depth > 0) {
 		int deltad = ascent_velocity(depth, avg_depth, bottom_time) * TIMESTEP;
 		if (deltad > depth)
 			deltad = depth;
-		update_cylinder_pressure(&displayed_dive, depth, depth - deltad, TIMESTEP, prefs.decosac, cylinder, true);
+		update_cylinder_pressure(&displayed_dive, depth, depth - deltad, TIMESTEP, prefs.decosac, cylinder, true, divemode);
 		if (depth <= 5000 && depth >= (5000 - deltad) && safety_stop) {
-			update_cylinder_pressure(&displayed_dive, 5000, 5000, 180, prefs.decosac, cylinder, true);
+			update_cylinder_pressure(&displayed_dive, 5000, 5000, 180, prefs.decosac, cylinder, true, divemode);
 			safety_stop = false;
 		}
 		depth -= deltad;
@@ -559,7 +566,7 @@ void track_ascent_gas(int depth, cylinder_t *cylinder, int avg_depth, int bottom
 }
 
 // Determine whether ascending to the next stop will break the ceiling.  Return true if the ascent is ok, false if it isn't.
-bool trial_ascent(struct deco_state *ds, int wait_time, int trial_depth, int stoplevel, int avg_depth, int bottom_time, struct gasmix *gasmix, int po2, double surface_pressure, struct dive *dive)
+bool trial_ascent(struct deco_state *ds, int wait_time, int trial_depth, int stoplevel, int avg_depth, int bottom_time, struct gasmix *gasmix, int po2, double surface_pressure, struct dive *dive, enum divemode_t divemode)
 {
 
 	bool clear_to_ascend = true;
@@ -572,7 +579,7 @@ bool trial_ascent(struct deco_state *ds, int wait_time, int trial_depth, int sto
 	if (wait_time)
 		add_segment(ds, depth_to_bar(trial_depth, dive),
 			    gasmix,
-			    wait_time, po2, dive, prefs.decosac);
+			    wait_time, po2, divemode, prefs.decosac);
 	if (decoMode() == VPMB && (deco_allowed_depth(tissue_tolerance_calc(ds, dive,depth_to_bar(stoplevel, dive)),
 						      surface_pressure, dive, 1)
 				   > stoplevel)) {
@@ -587,7 +594,7 @@ bool trial_ascent(struct deco_state *ds, int wait_time, int trial_depth, int sto
 			deltad = trial_depth;
 		add_segment(ds, depth_to_bar(trial_depth, dive),
 			    gasmix,
-			    TIMESTEP, po2, dive, prefs.decosac);
+			    TIMESTEP, po2, divemode, prefs.decosac);
 		if (deco_allowed_depth(tissue_tolerance_calc(ds, dive, depth_to_bar(trial_depth, dive)),
 				       surface_pressure, dive, 1) > trial_depth - deltad) {
 			/* We should have stopped */
@@ -624,7 +631,7 @@ bool enough_gas(int current_cylinder)
  * So we always test at the upper bundary, not in the middle!
  */
 
-int wait_until(struct deco_state *ds, struct dive *dive, int clock, int min, int leap, int stepsize, int depth, int target_depth, int avg_depth, int bottom_time, struct gasmix *gasmix, int po2, double surface_pressure)
+int wait_until(struct deco_state *ds, struct dive *dive, int clock, int min, int leap, int stepsize, int depth, int target_depth, int avg_depth, int bottom_time, struct gasmix *gasmix, int po2, double surface_pressure, enum divemode_t divemode)
 {
 	// When a deco stop exceeds two days, there is something wrong...
 	if (min >= 48 * 3600)
@@ -632,13 +639,13 @@ int wait_until(struct deco_state *ds, struct dive *dive, int clock, int min, int
 	// Round min + leap up to the next multiple of stepsize
 	int upper = min + leap + stepsize - 1 - (min + leap - 1) % stepsize;
 	// Is the upper boundary too small?
-	if (!trial_ascent(ds, upper - clock, depth, target_depth, avg_depth, bottom_time, gasmix, po2, surface_pressure, dive))
-		return wait_until(ds, dive, clock, upper, leap, stepsize, depth, target_depth, avg_depth, bottom_time, gasmix, po2, surface_pressure);
+	if (!trial_ascent(ds, upper - clock, depth, target_depth, avg_depth, bottom_time, gasmix, po2, surface_pressure, dive, divemode))
+		return wait_until(ds, dive, clock, upper, leap, stepsize, depth, target_depth, avg_depth, bottom_time, gasmix, po2, surface_pressure, divemode);
 
 	if (upper - min <= stepsize)
 		return upper;
 
-	return wait_until(ds, dive, clock, min, leap / 2, stepsize, depth, target_depth, avg_depth, bottom_time, gasmix, po2, surface_pressure);
+	return wait_until(ds, dive, clock, min, leap / 2, stepsize, depth, target_depth, avg_depth, bottom_time, gasmix, po2, surface_pressure, divemode);
 }
 
 // Work out the stops. Return value is if there were any mandatory stops.
@@ -689,6 +696,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 	int laststoptime = timestep;
 	bool o2breaking = false;
 	int decostopcounter = 0;
+	enum divemode_t divemode = dive->dc.divemode;
 
 	set_gf(diveplan->gflow, diveplan->gfhigh);
 	set_vpmb_conservatism(diveplan->vpmb_conservatism);
@@ -723,6 +731,10 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 	bottom_time = clock = previous_point_time = dive->dc.sample[dive->dc.samples - 1].time.seconds;
 
 	current_cylinder = get_cylinderid_at_time(dive, &dive->dc, sample->time);
+	// FIXME: This needs a function to find the divemode at the end of the dive like in
+	struct event *ev = NULL;
+	divemode = UNDEF_COMP_TYPE;
+	divemode = get_current_divemode(&dive->dc, bottom_time, &ev, &divemode);
 	gas = dive->cylinder[current_cylinder].gasmix;
 
 	po2 = sample->setpoint.mbar;
@@ -732,8 +744,11 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 
 	/* if all we wanted was the dive just get us back to the surface */
 	if (!is_planner) {
-		transitiontime = depth / 75; /* this still needs to be made configurable */
-		plan_add_segment(diveplan, transitiontime, 0, current_cylinder, po2, false);
+		/* Attn: for manually entered dives, we depend on the last segment having the
+		 * same ascent rate as in fake_dc(). If you change it here, also change it there.
+		 */
+		transitiontime = lrint(depth / (double)prefs.ascratelast6m);
+		plan_add_segment(diveplan, transitiontime, 0, current_cylinder, po2, false, divemode);
 		create_dive_from_plan(diveplan, dive, is_planner);
 		return false;
 	}
@@ -769,34 +784,33 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 	diveplan->surface_interval = tissue_at_end(ds, dive, cached_datap);
 	nuclear_regeneration(ds, clock);
 	vpmb_start_gradient(ds);
-
 	if (decoMode() == RECREATIONAL) {
 		bool safety_stop = prefs.safetystop && max_depth >= 10000;
-		track_ascent_gas(depth, &dive->cylinder[current_cylinder], avg_depth, bottom_time, safety_stop);
+		track_ascent_gas(depth, &dive->cylinder[current_cylinder], avg_depth, bottom_time, safety_stop, divemode);
 		// How long can we stay at the current depth and still directly ascent to the surface?
 		do {
 			add_segment(ds, depth_to_bar(depth, dive),
 				    &dive->cylinder[current_cylinder].gasmix,
-				    timestep, po2, dive, prefs.bottomsac);
-			update_cylinder_pressure(dive, depth, depth, timestep, prefs.bottomsac, &dive->cylinder[current_cylinder], false);
+				    timestep, po2, divemode, prefs.bottomsac);
+			update_cylinder_pressure(dive, depth, depth, timestep, prefs.bottomsac, &dive->cylinder[current_cylinder], false, divemode);
 			clock += timestep;
 		} while (trial_ascent(ds, 0, depth, 0, avg_depth, bottom_time, &dive->cylinder[current_cylinder].gasmix,
-				      po2, diveplan->surface_pressure / 1000.0, dive) &&
+				      po2, diveplan->surface_pressure / 1000.0, dive, divemode) &&
 			 enough_gas(current_cylinder) && clock < 6 * 3600);
 
 		// We did stay one DECOTIMESTEP too many.
 		// In the best of all worlds, we would roll back also the last add_segment in terms of caching deco state, but
 		// let's ignore that since for the eventual ascent in recreational mode, nobody looks at the ceiling anymore,
 		// so we don't really have to compute the deco state.
-		update_cylinder_pressure(dive, depth, depth, -timestep, prefs.bottomsac, &dive->cylinder[current_cylinder], false);
+		update_cylinder_pressure(dive, depth, depth, -timestep, prefs.bottomsac, &dive->cylinder[current_cylinder], false, divemode);
 		clock -= timestep;
-		plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, true);
+		plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, true, divemode);
 		previous_point_time = clock;
 		do {
 			/* Ascend to surface */
 			int deltad = ascent_velocity(depth, avg_depth, bottom_time) * TIMESTEP;
 			if (ascent_velocity(depth, avg_depth, bottom_time) != last_ascend_rate) {
-				plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, false);
+				plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, false, divemode);
 				previous_point_time = clock;
 				last_ascend_rate = ascent_velocity(depth, avg_depth, bottom_time);
 			}
@@ -806,15 +820,15 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 			clock += TIMESTEP;
 			depth -= deltad;
 			if (depth <= 5000 && depth >= (5000 - deltad) && safety_stop) {
-				plan_add_segment(diveplan, clock - previous_point_time, 5000, current_cylinder, po2, false);
+				plan_add_segment(diveplan, clock - previous_point_time, 5000, current_cylinder, po2, false, divemode);
 				previous_point_time = clock;
 				clock += 180;
-				plan_add_segment(diveplan, clock - previous_point_time, 5000, current_cylinder, po2, false);
+				plan_add_segment(diveplan, clock - previous_point_time, 5000, current_cylinder, po2, false, divemode);
 				previous_point_time = clock;
 				safety_stop = false;
 			}
 		} while (depth > 0);
-		plan_add_segment(diveplan, clock - previous_point_time, 0, current_cylinder, po2, false);
+		plan_add_segment(diveplan, clock - previous_point_time, 0, current_cylinder, po2, false, divemode);
 		create_dive_from_plan(diveplan, dive, is_planner);
 		add_plan_to_notes(diveplan, dive, show_disclaimer, error);
 		fixup_dc_duration(&dive->dc);
@@ -887,7 +901,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 				int deltad = ascent_velocity(depth, avg_depth, bottom_time) * TIMESTEP;
 				if (ascent_velocity(depth, avg_depth, bottom_time) != last_ascend_rate) {
 					if (is_final_plan)
-						plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, false);
+						plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, false, divemode);
 					previous_point_time = clock;
 					stopping = false;
 					last_ascend_rate = ascent_velocity(depth, avg_depth, bottom_time);
@@ -897,7 +911,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 
 				add_segment(ds, depth_to_bar(depth, dive),
 								&dive->cylinder[current_cylinder].gasmix,
-								TIMESTEP, po2, dive, prefs.decosac);
+								TIMESTEP, po2, divemode, prefs.decosac);
 				last_segment_min_switch = false;
 				clock += TIMESTEP;
 				depth -= deltad;
@@ -913,7 +927,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 				/* We have reached a gas change.
 				 * Record this in the dive plan */
 				if (is_final_plan)
-					plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, false);
+					plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, false, divemode);
 				previous_point_time = clock;
 				stopping = true;
 
@@ -925,7 +939,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 				if (current_cylinder != gaschanges[gi].gasidx) {
 					if (!prefs.switch_at_req_stop ||
 							!trial_ascent(ds, 0, depth, stoplevels[stopidx - 1], avg_depth, bottom_time,
-							&dive->cylinder[current_cylinder].gasmix, po2, diveplan->surface_pressure / 1000.0, dive) || get_o2(&dive->cylinder[current_cylinder].gasmix) < 160) {
+							&dive->cylinder[current_cylinder].gasmix, po2, diveplan->surface_pressure / 1000.0, dive, divemode) || get_o2(&dive->cylinder[current_cylinder].gasmix) < 160) {
 						current_cylinder = gaschanges[gi].gasidx;
 						gas = dive->cylinder[current_cylinder].gasmix;
 #if DEBUG_PLAN & 16
@@ -936,7 +950,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 						if (!last_segment_min_switch && get_o2(&dive->cylinder[current_cylinder].gasmix) != 1000) {
 							add_segment(ds, depth_to_bar(depth, dive),
 								&dive->cylinder[current_cylinder].gasmix,
-								prefs.min_switch_duration, po2, dive, prefs.decosac);
+								prefs.min_switch_duration, po2, divemode, prefs.decosac);
 							clock += prefs.min_switch_duration;
 							last_segment_min_switch = true;
 						}
@@ -955,7 +969,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 			while (1) {
 				/* Check if ascending to next stop is clear, go back and wait if we hit the ceiling on the way */
 				if (trial_ascent(ds, 0, depth, stoplevels[stopidx], avg_depth, bottom_time,
-						&dive->cylinder[current_cylinder].gasmix, po2, diveplan->surface_pressure / 1000.0, dive)) {
+						&dive->cylinder[current_cylinder].gasmix, po2, diveplan->surface_pressure / 1000.0, dive, divemode)) {
 					decostoptable[decostopcounter].depth = depth;
 					decostoptable[decostopcounter].time = 0;
 					decostopcounter++;
@@ -971,7 +985,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 					/* The last segment was an ascend segment.
 					 * Add a waypoint for start of this deco stop */
 					if (is_final_plan)
-						plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, false);
+						plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, false, divemode);
 					previous_point_time = clock;
 					stopping = true;
 				}
@@ -990,14 +1004,15 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 					if (!last_segment_min_switch && get_o2(&dive->cylinder[current_cylinder].gasmix) != 1000) {
 						add_segment(ds, depth_to_bar(depth, dive),
 							&dive->cylinder[current_cylinder].gasmix,
-							prefs.min_switch_duration, po2, dive, prefs.decosac);
+							prefs.min_switch_duration, po2, divemode, prefs.decosac);
 						clock += prefs.min_switch_duration;
 						last_segment_min_switch = true;
 					}
 					pendinggaschange = false;
 				}
 
-				int new_clock = wait_until(ds, dive, clock, clock, laststoptime * 2 + 1, timestep, depth, stoplevels[stopidx], avg_depth, bottom_time, &dive->cylinder[current_cylinder].gasmix, po2, diveplan->surface_pressure / 1000.0);
+				int new_clock = wait_until(ds, dive, clock, clock, laststoptime * 2 + 1, timestep, depth, stoplevels[stopidx], avg_depth,
+					bottom_time, &dive->cylinder[current_cylinder].gasmix, po2, diveplan->surface_pressure / 1000.0, divemode);
 				laststoptime = new_clock - clock;
 				/* Finish infinite deco */
 				if (laststoptime >= 48 * 3600 && depth >= 6000) {
@@ -1025,7 +1040,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 							o2break_next = true;
 							breakfrom_cylinder = current_cylinder;
 							if (is_final_plan)
-								plan_add_segment(diveplan, laststoptime, depth, current_cylinder, po2, false);
+								plan_add_segment(diveplan, laststoptime, depth, current_cylinder, po2, false, divemode);
 							previous_point_time = clock + laststoptime;
 							current_cylinder = break_cylinder;
 							gas = dive->cylinder[current_cylinder].gasmix;
@@ -1037,7 +1052,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 							o2breaking  = true;
 							o2break_next = false;
 							if (is_final_plan)
-								plan_add_segment(diveplan, laststoptime, depth, current_cylinder, po2, false);
+								plan_add_segment(diveplan, laststoptime, depth, current_cylinder, po2, false, divemode);
 							previous_point_time = clock + laststoptime;
 							current_cylinder = breakfrom_cylinder;
 							gas = dive->cylinder[current_cylinder].gasmix;
@@ -1045,7 +1060,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 					}
 				}
 				add_segment(ds, depth_to_bar(depth, dive), &dive->cylinder[stop_cylinder].gasmix,
-					    laststoptime, po2, dive, prefs.decosac);
+					    laststoptime, po2, divemode, prefs.decosac);
 				last_segment_min_switch = false;
 				decostoptable[decostopcounter].depth = depth;
 				decostoptable[decostopcounter].time = laststoptime;
@@ -1058,7 +1073,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 			if (stopping) {
 				/* Next we will ascend again. Add a waypoint if we have spend deco time */
 				if (is_final_plan)
-					plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, false);
+					plan_add_segment(diveplan, clock - previous_point_time, depth, current_cylinder, po2, false, divemode);
 				previous_point_time = clock;
 				stopping = false;
 			}
@@ -1071,7 +1086,7 @@ bool plan(struct deco_state *ds, struct diveplan *diveplan, struct dive *dive, i
 	} while (!is_final_plan);
 	decostoptable[decostopcounter].depth = 0;
 
-	plan_add_segment(diveplan, clock - previous_point_time, 0, current_cylinder, po2, false);
+	plan_add_segment(diveplan, clock - previous_point_time, 0, current_cylinder, po2, false, divemode);
 	if (decoMode() == VPMB) {
 		diveplan->eff_gfhigh = lrint(100.0 * regressionb());
 		diveplan->eff_gflow = lrint(100.0 * (regressiona() * first_stop_depth + regressionb()));
