@@ -2,12 +2,14 @@
 /* profile.c */
 /* creates all the necessary data for drawing the dive profile
  */
+#include "ssrf.h"
 #include "gettext.h"
 #include <limits.h>
 #include <string.h>
 #include <assert.h>
 
 #include "dive.h"
+#include "subsurface-string.h"
 #include "display.h"
 #include "divelist.h"
 
@@ -18,6 +20,7 @@
 #include "libdivecomputer/version.h"
 #include "membuffer.h"
 #include "qthelper.h"
+#include "format.h"
 
 //#define DEBUG_GAS 1
 
@@ -371,9 +374,9 @@ static int set_setpoint(struct plot_info *pi, int i, int setpoint, int end)
 
 static void check_setpoint_events(struct dive *dive, struct divecomputer *dc, struct plot_info *pi)
 {
+	UNUSED(dive);
 	int i = 0;
 	pressure_t setpoint;
-	(void) dive;
 	setpoint.mbar = 0;
 	struct event *ev = get_next_event(dc->events, "SP change");
 
@@ -500,12 +503,11 @@ struct plot_info calculate_max_limits_new(struct dive *dive, struct divecomputer
 
 struct plot_data *populate_plot_entries(struct dive *dive, struct divecomputer *dc, struct plot_info *pi)
 {
-
+	UNUSED(dive);
 	int idx, maxtime, nr, i;
 	int lastdepth, lasttime, lasttemp = 0;
 	struct plot_data *plot_data;
 	struct event *ev = dc->events;
-	(void) dive;
 	maxtime = pi->maxtime;
 
 	/*
@@ -791,8 +793,8 @@ static void calculate_sac(struct dive *dive, struct divecomputer *dc, struct plo
 
 static void populate_secondary_sensor_data(struct divecomputer *dc, struct plot_info *pi)
 {
-	(void) dc;
-	(void) pi;
+	UNUSED(dc);
+	UNUSED(pi);
 	/* We should try to see if it has interesting pressure data here */
 }
 
@@ -905,7 +907,7 @@ static void setup_gas_sensor_pressure(struct dive *dive, struct divecomputer *dc
 
 #ifndef SUBSURFACE_MOBILE
 /* calculate DECO STOP / TTS / NDL */
-static void calculate_ndl_tts(struct deco_state *ds, struct dive *dive, struct plot_data *entry, struct gasmix *gasmix, double surface_pressure)
+static void calculate_ndl_tts(struct deco_state *ds, struct dive *dive, struct plot_data *entry, struct gasmix *gasmix, double surface_pressure,enum divemode_t divemode)
 {
 	/* FIXME: This should be configurable */
 	/* ascent speed up to first deco stop */
@@ -940,7 +942,7 @@ static void calculate_ndl_tts(struct deco_state *ds, struct dive *dive, struct p
 		       ) {
 			entry->ndl_calc += time_stepsize;
 			add_segment(ds, depth_to_bar(entry->depth, dive),
-				    gasmix, time_stepsize, entry->o2pressure.mbar, dive, prefs.bottomsac);
+				    gasmix, time_stepsize, entry->o2pressure.mbar, divemode, prefs.bottomsac);
 		}
 		/* we don't need to calculate anything else */
 		return;
@@ -952,7 +954,7 @@ static void calculate_ndl_tts(struct deco_state *ds, struct dive *dive, struct p
 	/* Add segments for movement to stopdepth */
 	for (; ascent_depth > next_stop; ascent_depth -= ascent_mm_per_step, entry->tts_calc += ascent_s_per_step) {
 		add_segment(ds, depth_to_bar(ascent_depth, dive),
-			    gasmix, ascent_s_per_step, entry->o2pressure.mbar, dive, prefs.decosac);
+			    gasmix, ascent_s_per_step, entry->o2pressure.mbar, divemode, prefs.decosac);
 		next_stop = ROUND_UP(deco_allowed_depth(tissue_tolerance_calc(ds, dive, depth_to_bar(ascent_depth, dive)),
 							surface_pressure, dive, 1), deco_stepsize);
 	}
@@ -973,13 +975,13 @@ static void calculate_ndl_tts(struct deco_state *ds, struct dive *dive, struct p
 		if (entry->tts_calc > MAX_PROFILE_DECO)
 			break;
 		add_segment(ds, depth_to_bar(ascent_depth, dive),
-			    gasmix, time_stepsize, entry->o2pressure.mbar, dive, prefs.decosac);
+			    gasmix, time_stepsize, entry->o2pressure.mbar, divemode, prefs.decosac);
 
 		if (deco_allowed_depth(tissue_tolerance_calc(ds, dive, depth_to_bar(ascent_depth,dive)), surface_pressure, dive, 1) <= next_stop) {
 			/* move to the next stop and add the travel between stops */
 			for (; ascent_depth > next_stop; ascent_depth -= ascent_mm_per_deco_step, entry->tts_calc += ascent_s_per_deco_step)
 				add_segment(ds, depth_to_bar(ascent_depth, dive),
-					    gasmix, ascent_s_per_deco_step, entry->o2pressure.mbar, dive, prefs.decosac);
+					    gasmix, ascent_s_per_deco_step, entry->o2pressure.mbar, divemode, prefs.decosac);
 			ascent_depth = next_stop;
 			next_stop -= deco_stepsize;
 		}
@@ -994,6 +996,7 @@ void calculate_deco_information(struct deco_state *ds, struct deco_state *planne
 	double surface_pressure = (dc->surface_pressure.mbar ? dc->surface_pressure.mbar : get_surface_pressure_in_mbar(dive, true)) / 1000.0;
 	bool first_iteration = true;
 	int prev_deco_time = 10000000, time_deep_ceiling = 0;
+
 	if (!in_planner()) {
 		ds->deco_time = 0;
 	} else {
@@ -1008,20 +1011,22 @@ void calculate_deco_information(struct deco_state *ds, struct deco_state *planne
 	}
 	/* For VPM-B outside the planner, iterate until deco time converges (usually one or two iterations after the initial)
 	 * Set maximum number of iterations to 10 just in case */
+
 	while ((abs(prev_deco_time - ds->deco_time) >= 30) && (count_iteration < 10)) {
 		int last_ndl_tts_calc_time = 0, first_ceiling = 0, current_ceiling, last_ceiling = 0, final_tts = 0 , time_clear_ceiling = 0;
 		if (decoMode() == VPMB)
 			ds->first_ceiling_pressure.mbar = depth_to_mbar(first_ceiling, dive);
 		struct gasmix *gasmix = NULL;
-		struct event *ev = NULL;
+		struct event *ev = NULL, *evd = NULL;
+		enum divemode_t current_divemode = UNDEF_COMP_TYPE;
 
 		for (i = 1; i < pi->nr; i++) {
 			struct plot_data *entry = pi->entry + i;
 			int j, t0 = (entry - 1)->sec, t1 = entry->sec;
 			int time_stepsize = 20;
 
+			current_divemode = get_current_divemode(dc, entry->sec, &evd, &current_divemode);
 			gasmix = get_gasmix(dive, dc, t1, &ev, gasmix);
-
 			entry->ambpressure = depth_to_bar(entry->depth, dive);
 			entry->gfline = get_gf(ds, entry->ambpressure, dive) * (100.0 - AMB_PERCENTAGE) + AMB_PERCENTAGE;
 			if (t0 > t1) {
@@ -1035,7 +1040,8 @@ void calculate_deco_information(struct deco_state *ds, struct deco_state *planne
 			for (j = t0 + time_stepsize; j <= t1; j += time_stepsize) {
 				int depth = interpolate(entry[-1].depth, entry[0].depth, j - t0, t1 - t0);
 				add_segment(ds, depth_to_bar(depth, dive),
-					gasmix, time_stepsize, entry->o2pressure.mbar, dive, entry->sac);
+					    gasmix, time_stepsize, entry->o2pressure.mbar, current_divemode, entry->sac);
+				entry->icd_warning = ds->icd_warning;
 				if ((t1 - j < time_stepsize) && (j < t1))
 					time_stepsize = t1 - j;
 			}
@@ -1109,7 +1115,7 @@ void calculate_deco_information(struct deco_state *ds, struct deco_state *planne
 				/* We are going to mess up deco state, so store it for later restore */
 				struct deco_state *cache_data = NULL;
 				cache_deco_state(ds, &cache_data);
-				calculate_ndl_tts(ds, dive, entry, gasmix, surface_pressure);
+				calculate_ndl_tts(ds, dive, entry, gasmix, surface_pressure, current_divemode);
 				if (decoMode() == VPMB && !in_planner() && i == pi->nr - 1)
 					final_tts = entry->tts_calc;
 				/* Restore "real" deco state for next real time step */
@@ -1143,6 +1149,7 @@ void calculate_deco_information(struct deco_state *ds, struct deco_state *planne
 			prev_deco_time = ds->deco_time = 0;
 		}
 	}
+
 	free(cache_data_initial);
 #if DECO_CALC_DEBUG & 1
 	dump_tissues(ds);
@@ -1199,19 +1206,21 @@ static void calculate_gas_information_new(struct dive *dive, struct divecomputer
 	int i;
 	double amb_pressure;
 	struct gasmix *gasmix = NULL;
-	struct event *ev = NULL;
+	struct event *evg = NULL, *evd = NULL;
+	enum divemode_t current_divemode = UNDEF_COMP_TYPE;
 
 	for (i = 1; i < pi->nr; i++) {
 		int fn2, fhe;
 		struct plot_data *entry = pi->entry + i;
 
-		gasmix = get_gasmix(dive, dc, entry->sec, &ev, gasmix);
-
+		gasmix = get_gasmix(dive, dc, entry->sec, &evg, gasmix);
 		amb_pressure = depth_to_bar(entry->depth, dive);
-
-		fill_pressures(&entry->pressures, amb_pressure, gasmix, entry->o2pressure.mbar / 1000.0, dive->dc.divemode);
+		current_divemode = get_current_divemode(dc, entry->sec, &evd, &current_divemode);
+		fill_pressures(&entry->pressures, amb_pressure, gasmix, (current_divemode == OC) ? 0.0 : entry->o2pressure.mbar / 1000.0, current_divemode);
 		fn2 = (int)(1000.0 * entry->pressures.n2 / amb_pressure);
 		fhe = (int)(1000.0 * entry->pressures.he / amb_pressure);
+		if (dc->divemode == PSCR) // OC pO2 is calulated for PSCR with or without external PO2 monitoring.
+			entry->scr_OC_pO2.mbar = (int) depth_to_mbar(entry->depth, dive) * get_o2(get_gasmix(dive, dc, entry->sec, &evg, gasmix)) / 1000;
 
 		/* Calculate MOD, EAD, END and EADD based on partial pressures calculated before
 		 * so there is no difference in calculating between OC and CC
@@ -1313,7 +1322,7 @@ void create_plot_info_new(struct dive *dive, struct divecomputer *dc, struct plo
 	struct deco_state plot_deco_state;
 	init_decompression(&plot_deco_state, dive);
 #else
-	(void)planner_ds;
+	UNUSED(planner_ds);
 #endif
 	/* Create the new plot data */
 	free((void *)last_pi_entry_new);
@@ -1497,6 +1506,8 @@ static void plot_string(struct plot_info *pi, struct plot_data *entry, struct me
 			}
 		}
 	}
+	if (entry->icd_warning)
+		put_format(b, "%s", translate("gettextFromC", "ICD in leading tissue\n"));
 	if (entry->heartbeat && prefs.hrgraph)
 		put_format_loc(b, translate("gettextFromC", "heart rate: %d\n"), entry->heartbeat);
 	if (entry->bearing >= 0)
