@@ -46,6 +46,7 @@ struct plot_data {
 	pressure_t o2pressure;  // for rebreathers, this is consensus measured po2, or setpoint otherwise. 0 for OC.
 	pressure_t o2sensor[3]; //for rebreathers with up to 3 PO2 sensors
 	pressure_t o2setpoint;
+	pressure_t scr_OC_pO2;
 	double mod, ead, end, eadd;
 	velocity_t velocity;
 	int speed;
@@ -63,6 +64,7 @@ struct plot_data {
 	double ambpressure;
 	double gfline;
 	double density;
+	bool icd_warning;
 };
 
 struct ev_select {
