@@ -6,12 +6,12 @@ void init_qt_late();
 void init_ui();
 
 void run_ui();
+void register_qml_types();
 void exit_ui();
 void set_non_bt_addresses();
 
 #if defined(SUBSURFACE_MOBILE)
 #include <QQuickWindow>
-extern QObject *qqWindowObject;
 #endif
 
 #endif // QT_GUI_H
