@@ -1,5 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 #include <QApplication>
+#include <Qt>
 #include <QNetworkProxy>
 #include <QLibraryInfo>
 #include <QTextCodec>
@@ -42,6 +43,11 @@ void init_qt_late()
 		QCoreApplication::setApplicationName("Subsurface");
 #endif
 	}
+	// Disables the WindowContextHelpButtonHint by default on Qt::Sheet and Qt::Dialog widgets.
+	// This hides the ? button on Windows, which only makes sense if you use QWhatsThis functionality.
+#if QT_VERSION >= QT_VERSION_CHECK(5, 10, 0)
+	QCoreApplication::setAttribute(Qt::AA_DisableWindowContextHelpButton);
+#endif
 	// find plugins installed in the application directory (without this SVGs don't work on Windows)
 	SettingsObjectWrapper::instance()->load();
 
@@ -55,7 +61,7 @@ void init_qt_late()
 #if defined(Q_OS_ANDROID)
 	translationLocation = QLatin1Literal("assets:/translations");
 #elif defined(Q_OS_IOS)
-	translationLocation = QLatin1Literal(":/translations/");
+	translationLocation = QLatin1Literal(":/");
 #else
 	translationLocation = QLibraryInfo::location(QLibraryInfo::TranslationsPath);
 #endif
