@@ -610,14 +610,10 @@ static int save_one_picture(git_repository *repo, struct dir *dir, struct pictur
 	int offset = pic->offset.seconds;
 	struct membuffer buf = { 0 };
 	char sign = '+';
-	char *hash;
 	unsigned h;
 
 	show_utf8(&buf, "filename ", pic->filename, "\n");
 	show_gps(&buf, pic->latitude, pic->longitude);
-	hash = hashstring(pic->filename);
-	show_utf8(&buf, "hash ", hash, "\n");
-	free(hash);
 
 	/* Picture loading will load even negative offsets.. */
 	if (offset < 0) {
@@ -1058,16 +1054,19 @@ static int get_authorship(git_repository *repo, git_signature **authorp)
 	if (git_signature_default(authorp, repo) == 0)
 		return 0;
 #endif
-	/* Default name information, with potential OS overrides */
-	struct user_info user = {
-		.name = "Subsurface",
-		.email = "subsurface-app-account@subsurface-divelog.org"
-	};
-
+	/* try to fetch the user info from the OS, otherwise use default values. */
+	struct user_info user = { .name = NULL, .email = NULL };
 	subsurface_user_info(&user);
+	if (!user.name)
+		user.name = strdup("Subsurface");
+	if (!user.email)
+		user.email = strdup("subsurface-app-account@subsurface-divelog.org");
 
 	/* git_signature_default() is too recent */
-	return git_signature_now(authorp, user.name, user.email);
+	int ret = git_signature_now(authorp, user.name, user.email);
+	free((void *)user.name);
+	free((void *)user.email);
+	return ret;
 }
 
 static void create_commit_message(struct membuffer *msg, bool create_empty)
