@@ -155,7 +155,7 @@ void BtDeviceSelectionDialog::on_save_clicked()
 	selectedRemoteDeviceInfo.reset(new QBluetoothDeviceInfo(remoteDeviceInfo));
 	QString address = remoteDeviceInfo.address().isNull() ? remoteDeviceInfo.deviceUuid().toString() :
 								remoteDeviceInfo.address().toString();
-	saveBtDeviceInfo(address.toUtf8().constData(), remoteDeviceInfo);
+	saveBtDeviceInfo(address, remoteDeviceInfo);
 	if (remoteDeviceDiscoveryAgent->isActive()) {
 		// Stop the SDP agent if the clear button is pressed and enable the Scan button
 		remoteDeviceDiscoveryAgent->stop();
@@ -668,7 +668,7 @@ void WinBluetoothDeviceDiscoveryAgent::run()
 				// Get the last error and emit a signal
 				lastErrorToString = qt_error_string();
 				lastError = QBluetoothDeviceDiscoveryAgent::UnknownError;
-				emit(lastError);
+				emit error(lastError);
 
 				break;
 			}
@@ -682,7 +682,7 @@ void WinBluetoothDeviceDiscoveryAgent::run()
 			deviceAddress.truncate(BTH_ADDR_PRETTY_STRING_LEN);
 
 			// Create an object with information about the discovered device
-			QBluetoothDeviceInfo deviceInfo = QBluetoothDeviceInfo(QBluetoothAddress(deviceAddress), deviceName, 0);
+			QBluetoothDeviceInfo deviceInfo(QBluetoothAddress(deviceAddress), deviceName, 0);
 
 			// Raise a signal with information about the found remote device
 			emit deviceDiscovered(deviceInfo);
@@ -690,7 +690,7 @@ void WinBluetoothDeviceDiscoveryAgent::run()
 			// Get the last error and emit a signal
 			lastErrorToString = qt_error_string();
 			lastError = QBluetoothDeviceDiscoveryAgent::UnknownError;
-			emit(lastError);
+			emit error(lastError);
 		}
 	}
 
