@@ -49,23 +49,19 @@ ColumnNameProvider::ColumnNameProvider(QObject *parent) : QAbstractListModel(par
 		       tr("O₂") << tr("He") << tr("Sample time") << tr("Sample depth") << tr("Sample temperature") << tr("Sample pO₂") << tr("Sample CNS") << tr("Sample NDL") <<
 		       tr("Sample TTS") << tr("Sample stopdepth") << tr("Sample pressure") <<
 		       tr("Sample sensor1 pO₂") << tr("Sample sensor2 pO₂") << tr("Sample sensor3 pO₂") <<
-		       tr("Sample setpoint");
+		       tr("Sample setpoint") << tr("Visibility") << tr("Rating");
 }
 
-bool ColumnNameProvider::insertRows(int row, int count, const QModelIndex &parent)
+bool ColumnNameProvider::insertRows(int row, int, const QModelIndex&)
 {
-	Q_UNUSED(count)
-	Q_UNUSED(parent)
 	beginInsertRows(QModelIndex(), row, row);
 	columnNames.append(QString());
 	endInsertRows();
 	return true;
 }
 
-bool ColumnNameProvider::removeRows(int row, int count, const QModelIndex &parent)
+bool ColumnNameProvider::removeRows(int row, int, const QModelIndex&)
 {
-	Q_UNUSED(count)
-	Q_UNUSED(parent)
 	beginRemoveRows(QModelIndex(), row, row);
 	columnNames.removeAt(row);
 	endRemoveRows();
@@ -91,16 +87,17 @@ QVariant ColumnNameProvider::data(const QModelIndex &index, int role) const
 	return QVariant(columnNames[index.row()]);
 }
 
-int ColumnNameProvider::rowCount(const QModelIndex &parent) const
+int ColumnNameProvider::rowCount(const QModelIndex&) const
 {
-	Q_UNUSED(parent)
 	return columnNames.count();
 }
 
 int ColumnNameProvider::mymatch(QString value) const
 {
 	QString searchString = value.toLower();
-	searchString.replace("\"", "").replace(" ", "").replace(".", "").replace("\n","");
+	QRegExp re(" \\(.*\\)");
+
+	searchString.replace("\"", "").replace(re, "").replace(" ", "").replace(".", "").replace("\n","");
 	for (int i = 0; i < columnNames.count(); i++) {
 		QString name = columnNames.at(i).toLower();
 		name.replace("\"", "").replace(" ", "").replace(".", "").replace("\n","");
@@ -112,9 +109,8 @@ int ColumnNameProvider::mymatch(QString value) const
 
 
 
-ColumnNameView::ColumnNameView(QWidget *parent)
+ColumnNameView::ColumnNameView(QWidget*)
 {
-	Q_UNUSED(parent)
 	setAcceptDrops(true);
 	setDragEnabled(true);
 }
@@ -143,9 +139,8 @@ void ColumnNameView::mousePressEvent(QMouseEvent *press)
 	}
 }
 
-void ColumnNameView::dragLeaveEvent(QDragLeaveEvent *leave)
+void ColumnNameView::dragLeaveEvent(QDragLeaveEvent*)
 {
-	Q_UNUSED(leave);
 }
 
 void ColumnNameView::dragEnterEvent(QDragEnterEvent *event)
@@ -174,15 +169,13 @@ void ColumnNameView::dropEvent(QDropEvent *event)
 	}
 }
 
-ColumnDropCSVView::ColumnDropCSVView(QWidget *parent)
+ColumnDropCSVView::ColumnDropCSVView(QWidget*)
 {
-	Q_UNUSED(parent)
 	setAcceptDrops(true);
 }
 
-void ColumnDropCSVView::dragLeaveEvent(QDragLeaveEvent *leave)
+void ColumnDropCSVView::dragLeaveEvent(QDragLeaveEvent*)
 {
-	Q_UNUSED(leave);
 }
 
 void ColumnDropCSVView::dragEnterEvent(QDragEnterEvent *event)
@@ -270,15 +263,13 @@ QVariant ColumnNameResult::data(const QModelIndex &index, int role) const
 		return QVariant();
 }
 
-int ColumnNameResult::rowCount(const QModelIndex &parent) const
+int ColumnNameResult::rowCount(const QModelIndex&) const
 {
-	Q_UNUSED(parent);
 	return columnValues.count() + 1; // +1 == the header.
 }
 
-int ColumnNameResult::columnCount(const QModelIndex &parent) const
+int ColumnNameResult::columnCount(const QModelIndex&) const
 {
-	Q_UNUSED(parent);
 	return columnNames.count();
 }
 
@@ -780,8 +771,12 @@ int DiveLogImportDialog::setup_csv_params(QStringList r, char **params, int pnr)
 	params[pnr++] = intdup(r.indexOf(tr("Sample stopdepth")));
 	params[pnr++] = strdup("pressureField");
 	params[pnr++] = intdup(r.indexOf(tr("Sample pressure")));
-	params[pnr++] = strdup("setpointFiend");
+	params[pnr++] = strdup("setpointField");
 	params[pnr++] = intdup(r.indexOf(tr("Sample setpoint")));
+	params[pnr++] = strdup("visibilityField");
+	params[pnr++] = intdup(r.indexOf(tr("Visibility")));
+	params[pnr++] = strdup("ratingField");
+	params[pnr++] = intdup(r.indexOf(tr("Rating")));
 	params[pnr++] = strdup("separatorIndex");
 	params[pnr++] = intdup(ui->CSVSeparator->currentIndex());
 	params[pnr++] = strdup("units");
@@ -873,7 +868,7 @@ void DiveLogImportDialog::on_buttonBox_accepted()
 	} else {
 		for (int i = 0; i < fileNames.size(); ++i) {
 			if (r.indexOf(tr("Sample time")) < 0) {
-				char *params[55];
+				char *params[59];
 				int pnr = 0;
 				params[pnr++] = strdup("numberField");
 				params[pnr++] = intdup(r.indexOf(tr("Dive #")));
@@ -925,6 +920,10 @@ void DiveLogImportDialog::on_buttonBox_accepted()
 				params[pnr++] = intdup(r.indexOf(tr("Air temp.")));
 				params[pnr++] = strdup("watertempField");
 				params[pnr++] = intdup(r.indexOf(tr("Water temp.")));
+				params[pnr++] = strdup("visibilityField");
+				params[pnr++] = intdup(r.indexOf(tr("Visibility")));
+				params[pnr++] = strdup("ratingField");
+				params[pnr++] = intdup(r.indexOf(tr("Rating")));
 				params[pnr++] = NULL;
 
 				parse_manual_file(qPrintable(fileNames[i]), params, pnr - 1);
