@@ -3,10 +3,9 @@
 #include "ui_TabDiveInformation.h"
 #include "../tagwidget.h"
 
-#include <core/helpers.h>
+#include <core/qthelper.h>
 #include <core/statistics.h>
 #include <core/display.h>
-#include <core/dive.h>
 
 TabDiveInformation::TabDiveInformation(QWidget *parent) : TabBase(parent), ui(new Ui::TabDiveInformation())
 {
