@@ -8,7 +8,7 @@
 #include "desktop-widgets/tab-widgets/maintab.h"
 #include "desktop-widgets/mainwindow.h"
 #include "desktop-widgets/mapwidget.h"
-#include "core/helpers.h"
+#include "core/qthelper.h"
 #include "core/statistics.h"
 #include "desktop-widgets/modeldelegates.h"
 #include "qt-models/diveplannermodel.h"
@@ -23,7 +23,8 @@
 #include "qt-models/divelocationmodel.h"
 #include "qt-models/filtermodels.h"
 #include "core/divesite.h"
-#include "desktop-widgets/locationinformation.h"
+#include "core/subsurface-string.h"
+#include "core/gettextfromc.h"
 #include "desktop-widgets/locationinformation.h"
 
 #include "TabDiveExtraInfo.h"
@@ -61,6 +62,7 @@ MainTab::MainTab(QWidget *parent) : QTabWidget(parent),
 	ui.tabWidget->addTab(extraWidgets.last(), tr("Extra Info"));
 
 	ui.dateEdit->setDisplayFormat(prefs.date_format);
+	ui.timeEdit->setDisplayFormat(prefs.time_format);
 
 	memset(&displayed_dive, 0, sizeof(displayed_dive));
 	memset(&displayedTrip, 0, sizeof(displayedTrip));
@@ -108,7 +110,10 @@ MainTab::MainTab(QWidget *parent) : QTabWidget(parent),
 	connect(ui.weights, SIGNAL(addButtonClicked()), this, SLOT(addWeight_clicked()));
 
 	// This needs to be the same order as enum dive_comp_type in dive.h!
-	ui.DiveType->insertItems(0, QStringList() << tr("OC") << tr("CCR") << tr("pSCR") << tr("Freedive"));
+	QStringList types = QStringList();
+	for (int i = 0; i < NUM_DIVEMODE; i++)
+		types.append(gettextFromC::tr(divemode_text_ui[i]));
+	ui.DiveType->insertItems(0, types);
 	connect(ui.DiveType, SIGNAL(currentIndexChanged(int)), this, SLOT(divetype_Changed(int)));
 
 	connect(ui.cylinders->view(), SIGNAL(clicked(QModelIndex)), this, SLOT(editCylinderWidget(QModelIndex)));
@@ -334,6 +339,7 @@ void MainTab::enableEdition(EditMode newEditMode)
 	ui.editDiveSiteButton->setEnabled(false);
 	MainWindow::instance()->dive_list()->setEnabled(false);
 	MainWindow::instance()->setEnabledToolbar(false);
+	MainWindow::instance()->enterEditState();
 
 	if (isTripEdit) {
 		// we are editing trip location and notes
@@ -417,7 +423,6 @@ void MainTab::updateDiveInfo(bool clear)
 	// for the trip in the Info tab, otherwise we show the info of the
 	// selected_dive
 	struct dive *prevd;
-	char buf[1024];
 
 	process_selected_dives();
 	process_all_dives(&displayed_dive, &prevd);
@@ -570,8 +575,7 @@ void MainTab::updateDiveInfo(bool clear)
 			ui.equipmentTab->setEnabled(true);
 			cylindersModel->updateDive();
 			weightModel->updateDive();
-			taglist_get_tagstring(displayed_dive.tag_list, buf, 1024);
-			ui.tagWidget->setText(QString(buf));
+			ui.tagWidget->setText(get_taglist_string(displayed_dive.tag_list));
 			if (current_dive) {
 				bool isManual = same_string(current_dive->dc.model, "manually added dive");
 				ui.depth->setVisible(isManual);
@@ -993,6 +997,7 @@ void MainTab::acceptChanges()
 	DivePlannerPointsModel::instance()->setPlanMode(DivePlannerPointsModel::NOTHING);
 	MainWindow::instance()->dive_list()->verticalScrollBar()->setSliderPosition(scrolledBy);
 	MainWindow::instance()->dive_list()->setFocus();
+	MainWindow::instance()->exitEditState();
 	cylindersModel->changed = false;
 	weightModel->changed = false;
 	MainWindow::instance()->setEnabledToolbar(true);
@@ -1026,7 +1031,7 @@ void MainTab::rejectChanges()
 	if (lastMode != NONE && current_dive &&
 	    (modified ||
 	     memcmp(&current_dive->cylinder[0], &displayed_dive.cylinder[0], sizeof(cylinder_t) * MAX_CYLINDERS) ||
-	     memcmp(&current_dive->cylinder[0], &displayed_dive.weightsystem[0], sizeof(weightsystem_t) * MAX_WEIGHTSYSTEMS))) {
+	     memcmp(&current_dive->weightsystem[0], &displayed_dive.weightsystem[0], sizeof(weightsystem_t) * MAX_WEIGHTSYSTEMS))) {
 		if (QMessageBox::warning(MainWindow::instance(), TITLE_OR_TEXT(tr("Discard the changes?"),
 									       tr("You are about to discard your changes.")),
 					 QMessageBox::Discard | QMessageBox::Cancel, QMessageBox::Discard) != QMessageBox::Discard) {
@@ -1060,6 +1065,7 @@ void MainTab::rejectChanges()
 	// show the profile and dive info
 	MainWindow::instance()->graphics()->replot();
 	MainWindow::instance()->setEnabledToolbar(true);
+	MainWindow::instance()->exitEditState();
 	cylindersModel->changed = false;
 	weightModel->changed = false;
 	cylindersModel->updateDive();
@@ -1162,7 +1168,7 @@ void MainTab::divetype_Changed(int index)
 {
 	if (editMode == IGNORE)
 		return;
-	displayed_dc->divemode = (enum dive_comp_type) index;
+	displayed_dc->divemode = (enum divemode_t) index;
 	update_setpoint_events(&displayed_dive, displayed_dc);
 	markChangedWidget(ui.DiveType);
 	MainWindow::instance()->graphics()->recalcCeiling();
@@ -1347,13 +1353,10 @@ void MainTab::diffTaggedStrings(QString currentString, QString displayedString,
 
 void MainTab::on_tagWidget_textChanged()
 {
-	char buf[1024];
-
 	if (editMode == IGNORE || acceptingEdit == true)
 		return;
 
-	taglist_get_tagstring(displayed_dive.tag_list, buf, 1024);
-	if (same_string(buf, qPrintable(ui.tagWidget->toPlainText())))
+	if (get_taglist_string(displayed_dive.tag_list) == ui.tagWidget->toPlainText())
 		return;
 
 	markChangedWidget(ui.tagWidget);
@@ -1524,9 +1527,7 @@ void MainTab::showAndTriggerEditSelective(struct dive_components what)
 	if (what.divesite)
 		ui.location->setCurrentDiveSiteUuid(displayed_dive.dive_site_uuid);
 	if (what.tags) {
-		char buf[1024];
-		taglist_get_tagstring(displayed_dive.tag_list, buf, 1024);
-		ui.tagWidget->setText(QString(buf));
+		ui.tagWidget->setText(get_taglist_string(displayed_dive.tag_list));
 	}
 	if (what.cylinders) {
 		cylindersModel->updateDive();
