@@ -5,9 +5,8 @@
 #include <QVector>
 
 #include "qmlmapwidgethelper.h"
-#include "core/dive.h"
 #include "core/divesite.h"
-#include "core/helpers.h"
+#include "core/qthelper.h"
 #include "qt-models/maplocationmodel.h"
 
 #define MIN_DISTANCE_BETWEEN_DIVE_SITES_M 50.0
