@@ -38,8 +38,8 @@ BUILD_NR=0
 SUBSURFACE_DESKTOP=OFF
 # Which arch should we build for?
 ARCH=arm
-# Which SDK buildtools revision is used?
-ANDROID_BUILDTOOLS_REVISION=25.0.3
+# Read build variables
+source subsurface/packaging/android/variables.sh 
 
 while [ "$#" -gt 0 ] ; do
 	case "$1" in
@@ -76,12 +76,12 @@ done
 export ARCH
 
 # Configure where we can find things here
-export ANDROID_NDK_ROOT=${ANDROID_NDK_ROOT-$SUBSURFACE_SOURCE/../android-ndk-r14b}
+export ANDROID_NDK_ROOT=${ANDROID_NDK_ROOT-$SUBSURFACE_SOURCE/../${ANDROID_NDK}}
 
 if [ -n "${QT5_ANDROID+X}" ] ; then
 	echo "Using Qt5 in $QT5_ANDROID"
-elif [ -d "$SUBSURFACE_SOURCE/../Qt/5.10.1" ] ; then
-	export QT5_ANDROID=$SUBSURFACE_SOURCE/../Qt/5.10.1
+elif [ -d "$SUBSURFACE_SOURCE/../Qt/${LATEST_QT}" ] ; then
+	export QT5_ANDROID=$SUBSURFACE_SOURCE/../Qt/${LATEST_QT}
 elif [ -d "$SUBSURFACE_SOURCE/../Qt/5.9.3" ] ; then
 	export QT5_ANDROID=$SUBSURFACE_SOURCE/../Qt/5.9.3
 elif [ -d "$SUBSURFACE_SOURCE/../Qt/5.9.1" ] ; then
@@ -90,14 +90,8 @@ elif [ -d "$SUBSURFACE_SOURCE/../Qt/5.9" ] ; then
 	export QT5_ANDROID=$SUBSURFACE_SOURCE/../Qt/5.9
 elif [ -d "$SUBSURFACE_SOURCE/../Qt/5.8" ] ; then
 	export QT5_ANDROID=$SUBSURFACE_SOURCE/../Qt/5.8
-elif [ -d "$SUBSURFACE_SOURCE/../Qt/5.7" ] ; then
-	export QT5_ANDROID=$SUBSURFACE_SOURCE/../Qt/5.7
-elif [ -d "$SUBSURFACE_SOURCE/../Qt/5.6" ] ; then
-	export QT5_ANDROID=$SUBSURFACE_SOURCE/../Qt/5.6
-elif [ -d "$SUBSURFACE_SOURCE/../Qt/5.5" ] ; then
-	export QT5_ANDROID=$SUBSURFACE_SOURCE/../Qt/5.5
 else
-	echo "Cannot find Qt 5.5 or newer under $SUBSURFACE_SOURCE/../Qt"
+	echo "Cannot find Qt 5.8 or newer under $SUBSURFACE_SOURCE/../Qt"
 	exit 1
 fi
 
@@ -109,9 +103,6 @@ else
 	export ANDROID_NDK_HOST=linux-x86_64
 fi
 
-# Which versions are we building against?
-OPENSSL_VERSION=1.0.2l
-
 if [ "$ARCH" = "arm" ] ; then
 	QT_ARCH=armv7
 	BUILDCHAIN=arm-linux-androideabi
@@ -162,7 +153,7 @@ QMAKE=$QT5_ANDROID/android_armv7/bin/qmake
 $QMAKE -query
 
 # build google maps plugin
-${SUBSURFACE_SOURCE}/scripts/get-dep-lib.sh singleAndroid . googlemaps
+"${SUBSURFACE_SOURCE}"/scripts/get-dep-lib.sh singleAndroid . googlemaps
 # find qmake
 QMAKE=$QT5_ANDROID/android_armv7/bin/qmake
 $QMAKE -query
@@ -181,7 +172,7 @@ if [ ! -e "$QT_PLUGINS_PATH"/geoservices/$GOOGLEMAPS_BIN ] || [ googlemaps/.git/
     popd
 fi
 
-${SUBSURFACE_SOURCE}/scripts/get-dep-lib.sh singleAndroid . sqlite
+"${SUBSURFACE_SOURCE}"/scripts/get-dep-lib.sh singleAndroid . sqlite
 if [ ! -e "$PKG_CONFIG_LIBDIR/sqlite3.pc" ] ; then
 	mkdir -p sqlite-build-"$ARCH"
 	pushd sqlite-build-"$ARCH"
@@ -191,7 +182,7 @@ if [ ! -e "$PKG_CONFIG_LIBDIR/sqlite3.pc" ] ; then
 	popd
 fi
 
-${SUBSURFACE_SOURCE}/scripts/get-dep-lib.sh singleAndroid . libxml2
+"${SUBSURFACE_SOURCE}"/scripts/get-dep-lib.sh singleAndroid . libxml2
 if [ ! -e libxml2/configure ] ; then
 	pushd libxml2
 	autoreconf --install
@@ -208,7 +199,7 @@ if [ ! -e "$PKG_CONFIG_LIBDIR/libxml-2.0.pc" ] ; then
 	popd
 fi
 
-${SUBSURFACE_SOURCE}/scripts/get-dep-lib.sh singleAndroid . libxslt
+"${SUBSURFACE_SOURCE}"/scripts/get-dep-lib.sh singleAndroid . libxslt
 if [ ! -e libxslt/configure ] ; then
 	pushd libxslt
 	autoreconf --install
@@ -223,7 +214,7 @@ if [ ! -e "$PKG_CONFIG_LIBDIR/libxslt.pc" ] ; then
 	popd
 fi
 
-${SUBSURFACE_SOURCE}/scripts/get-dep-lib.sh singleAndroid . libzip
+"${SUBSURFACE_SOURCE}"/scripts/get-dep-lib.sh singleAndroid . libzip
 if [ ! -e "$PKG_CONFIG_LIBDIR/libzip.pc" ] ; then
 	mkdir -p libzip-build-"$ARCH"
 	pushd libzip-build-"$ARCH"
@@ -233,7 +224,7 @@ if [ ! -e "$PKG_CONFIG_LIBDIR/libzip.pc" ] ; then
 	popd
 fi
 
-${SUBSURFACE_SOURCE}/scripts/get-dep-lib.sh singleAndroid . openssl
+"${SUBSURFACE_SOURCE}"/scripts/get-dep-lib.sh singleAndroid . openssl
 if [ ! -e openssl-build-"$ARCH" ] ; then
 	mv openssl openssl-build-"$ARCH"
 fi
@@ -257,7 +248,7 @@ if [ ! -e "$PKG_CONFIG_LIBDIR/libssl.pc" ] ; then
 	popd
 fi
 
-${SUBSURFACE_SOURCE}/scripts/get-dep-lib.sh singleAndroid . libgit2
+"${SUBSURFACE_SOURCE}"/scripts/get-dep-lib.sh singleAndroid . libgit2
 if [ ! -e "$PKG_CONFIG_LIBDIR/libgit2.pc" ] ; then
 	# We don't want to find the HTTP_Parser package of the build host by mistake
 	perl -pi -e 's/FIND_PACKAGE\(HTTP_Parser\)/#FIND_PACKAGE(HTTP_Parser)/' libgit2/CMakeLists.txt
@@ -273,7 +264,7 @@ if [ ! -e "$PKG_CONFIG_LIBDIR/libgit2.pc" ] ; then
 		-DOPENSSL_SSL_LIBRARY="$PREFIX"/lib/libssl.so \
 		-DOPENSSL_CRYPTO_LIBRARY="$PREFIX"/lib/libcrypto.so \
 		-DOPENSSL_INCLUDE_DIR="$PREFIX"/include/openssl \
-		-D_OPENSSL_VERSION=${OPENSSL_VERSION} \
+		-D_OPENSSL_VERSION="${OPENSSL_VERSION}" \
 		../libgit2/
 	make
 	make install
@@ -282,7 +273,7 @@ if [ ! -e "$PKG_CONFIG_LIBDIR/libgit2.pc" ] ; then
 	popd
 fi
 
-${SUBSURFACE_SOURCE}/scripts/get-dep-lib.sh singleAndroid . libusb
+"${SUBSURFACE_SOURCE}"/scripts/get-dep-lib.sh singleAndroid . libusb
 if ! grep -q libusb_set_android_open_callback libusb/libusb/libusb.h ; then
 	# Patch in our libusb callback
 	pushd libusb
@@ -305,7 +296,7 @@ if [ ! -e "$PKG_CONFIG_LIBDIR/libusb-1.0.pc" ] ; then
 	popd
 fi
 
-${SUBSURFACE_SOURCE}/scripts/get-dep-lib.sh singleAndroid . libftdi1
+"${SUBSURFACE_SOURCE}"/scripts/get-dep-lib.sh singleAndroid . libftdi1
 if [ ! -e "$PKG_CONFIG_LIBDIR/libftdi1.pc" ] && [ "$PLATFORM" != "Darwin" ] ; then
 	mkdir -p libftdi1-build-"$ARCH"
 	pushd libftdi1-build-"$ARCH"
