@@ -1,7 +1,8 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "profile-widget/divecartesianaxis.h"
 #include "profile-widget/divetextitem.h"
-#include "core/helpers.h"
+#include "core/qthelper.h"
+#include "core/subsurface-string.h"
 #include "core/subsurface-qt/SettingsObjectWrapper.h"
 #ifndef SUBSURFACE_MOBILE
 #include "desktop-widgets/preferences/preferencesdialog.h"
@@ -98,9 +99,8 @@ void DiveCartesianAxis::setOrientation(Orientation o)
 	changed = true;
 }
 
-QColor DiveCartesianAxis::colorForValue(double value)
+QColor DiveCartesianAxis::colorForValue(double)
 {
-	Q_UNUSED(value)
 	return QColor(Qt::black);
 }
 
@@ -127,13 +127,11 @@ void DiveCartesianAxis::setLinesVisible(bool arg1)
 }
 
 template <typename T>
-void emptyList(QList<T *> &list, double steps)
+void emptyList(QList<T *> &list, int steps)
 {
-	if (!list.isEmpty() && list.size() > steps) {
-		while (list.size() > steps) {
-			T *removedItem = list.takeLast();
-			Animations::animDelete(removedItem);
-		}
+	while (list.size() > steps) {
+		T *removedItem = list.takeLast();
+		Animations::animDelete(removedItem);
 	}
 }
 
@@ -144,7 +142,8 @@ void DiveCartesianAxis::updateTicks(color_index_t color)
 	QLineF m = line();
 	// unused so far:
 	// QGraphicsView *view = scene()->views().first();
-	double steps = (max - min) / interval;
+	double stepsInRange = (max - min) / interval;
+	int steps = (int)stepsInRange;
 	double currValueText = min;
 	double currValueLine = min;
 
@@ -154,8 +153,8 @@ void DiveCartesianAxis::updateTicks(color_index_t color)
 	emptyList(labels, steps);
 	emptyList(lines, steps);
 
-	// Move the remaining Ticks / Text to it's corerct position
-	// Regartind the possibly new values for the Axis
+	// Move the remaining ticks / text to their correct positions
+	// regarding the possible new values for the axis
 	qreal begin, stepSize;
 	if (orientation == TopToBottom) {
 		begin = m.y1();
@@ -170,7 +169,7 @@ void DiveCartesianAxis::updateTicks(color_index_t color)
 		begin = m.x2();
 		stepSize = (m.x2() - m.x1());
 	}
-	stepSize = stepSize / steps;
+	stepSize /= stepsInRange;
 
 	for (int i = 0, count = labels.size(); i < count; i++, currValueText += interval) {
 		qreal childPos = (orientation == TopToBottom || orientation == LeftToRight) ?
@@ -355,9 +354,8 @@ QString DepthAxis::textForValue(double value)
 	return get_depth_string(lrint(value), false, false);
 }
 
-QColor DepthAxis::colorForValue(double value)
+QColor DepthAxis::colorForValue(double)
 {
-	Q_UNUSED(value);
 	return QColor(Qt::red);
 }
 
@@ -384,9 +382,8 @@ TimeAxis::TimeAxis(ProfileWidget2 *widget) : DiveCartesianAxis(widget)
 {
 }
 
-QColor TimeAxis::colorForValue(double value)
+QColor TimeAxis::colorForValue(double)
 {
-	Q_UNUSED(value);
 	return QColor(Qt::blue);
 }
 
