@@ -4,14 +4,12 @@
 #include "profile-widget/divecartesianaxis.h"
 #include "profile-widget/divetextitem.h"
 #include "profile-widget/animationfunctions.h"
-#include "core/dive.h"
 #include "core/profile.h"
 #ifndef SUBSURFACE_MOBILE
 #include "desktop-widgets/preferences/preferencesdialog.h"
 #endif
 #include "qt-models/diveplannermodel.h"
-#include "core/helpers.h"
-#include "core/dive.h"
+#include "core/qthelper.h"
 #include "core/subsurface-qt/SettingsObjectWrapper.h"
 #include "libdivecomputer/parser.h"
 #include "profile-widget/profilewidget2.h"
@@ -54,11 +52,8 @@ void AbstractProfilePolygonItem::setModel(DivePlotDataModel *model)
 	modelDataChanged();
 }
 
-void AbstractProfilePolygonItem::modelDataRemoved(const QModelIndex &parent, int from, int to)
+void AbstractProfilePolygonItem::modelDataRemoved(const QModelIndex&, int, int)
 {
-	Q_UNUSED(from);
-	Q_UNUSED(parent);
-	Q_UNUSED(to);
 	setPolygon(QPolygonF());
 	qDeleteAll(texts);
 	texts.clear();
@@ -95,10 +90,8 @@ bool AbstractProfilePolygonItem::shouldCalculateStuff(const QModelIndex &topLeft
 	return true;
 }
 
-void AbstractProfilePolygonItem::modelDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight)
+void AbstractProfilePolygonItem::modelDataChanged(const QModelIndex&, const QModelIndex&)
 {
-	Q_UNUSED(topLeft);
-	Q_UNUSED(bottomRight);
 	// Calculate the polygon. This is the polygon that will be painted on screen
 	// on the ::paint method. Here we calculate the correct position of the points
 	// regarting our cartesian plane ( made by the hAxis and vAxis ), the QPolygonF
@@ -123,15 +116,13 @@ DiveProfileItem::DiveProfileItem() : show_reported_ceiling(0), reported_ceiling_
 	connect(SettingsObjectWrapper::instance()->techDetails, &TechnicalDetailsSettings::redceilingChanged, this, &DiveProfileItem::settingsToggled);
 }
 
-void DiveProfileItem::settingsToggled(bool toggled)
+void DiveProfileItem::settingsToggled(bool)
 {
-	Q_UNUSED(toggled);
 	settingsChanged();
 }
 
 void DiveProfileItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
 {
-	Q_UNUSED(widget);
 	if (polygon().isEmpty())
 		return;
 
@@ -172,7 +163,6 @@ int DiveProfileItem::maxCeiling(int row)
 void DiveProfileItem::modelDataChanged(const QModelIndex &topLeft, const QModelIndex &bottomRight)
 {
 	bool eventAdded = false;
-	(void)eventAdded;
 	if (!shouldCalculateStuff(topLeft, bottomRight))
 		return;
 
@@ -184,7 +174,9 @@ void DiveProfileItem::modelDataChanged(const QModelIndex &topLeft, const QModelI
 	reported_ceiling_in_red = prefs.redceiling;
 	profileColor = getColor(DEPTH_BOTTOM);
 
-#ifndef SUBSURFACE_MOBILE
+#ifdef SUBSURFACE_MOBILE
+	Q_UNUSED(eventAdded);
+#else
 	int currState = qobject_cast<ProfileWidget2 *>(scene()->views().first())->currentState;
 	if (currState == ProfileWidget2::PLAN) {
 		plot_data *entry = dataModel->data().entry;
@@ -344,10 +336,8 @@ void DiveHeartrateItem::createTextItem(int sec, int hr)
 	texts.append(text);
 }
 
-void DiveHeartrateItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+void DiveHeartrateItem::paint(QPainter *painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
-	Q_UNUSED(option);
-	Q_UNUSED(widget);
 	if (polygon().isEmpty())
 		return;
 	painter->save();
@@ -408,11 +398,8 @@ QColor DivePercentageItem::ColorScale(double value, int inert)
 
 }
 
-void DivePercentageItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+void DivePercentageItem::paint(QPainter *painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
-	Q_UNUSED(option);
-	Q_UNUSED(widget);
-
 	if (polygon().isEmpty())
 		return;
 	painter->save();
@@ -470,11 +457,8 @@ void DiveAmbPressureItem::modelDataChanged(const QModelIndex &topLeft, const QMo
 		texts.last()->setAlignment(Qt::AlignLeft | Qt::AlignBottom);
 }
 
-void DiveAmbPressureItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+void DiveAmbPressureItem::paint(QPainter *painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
-	Q_UNUSED(option);
-	Q_UNUSED(widget);
-
 	if (polygon().isEmpty())
 		return;
 	painter->save();
@@ -518,11 +502,8 @@ void DiveGFLineItem::modelDataChanged(const QModelIndex &topLeft, const QModelIn
 		texts.last()->setAlignment(Qt::AlignLeft | Qt::AlignBottom);
 }
 
-void DiveGFLineItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+void DiveGFLineItem::paint(QPainter *painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
-	Q_UNUSED(option);
-	Q_UNUSED(widget);
-
 	if (polygon().isEmpty())
 		return;
 	painter->save();
@@ -601,11 +582,8 @@ void DiveTemperatureItem::createTextItem(int sec, int mkelvin)
 	texts.append(text);
 }
 
-void DiveTemperatureItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+void DiveTemperatureItem::paint(QPainter *painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
-	Q_UNUSED(option);
-	Q_UNUSED(widget);
-
 	if (polygon().isEmpty())
 		return;
 	painter->save();
@@ -649,11 +627,8 @@ void DiveMeanDepthItem::modelDataChanged(const QModelIndex &topLeft, const QMode
 }
 
 
-void DiveMeanDepthItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+void DiveMeanDepthItem::paint(QPainter *painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
-	Q_UNUSED(option);
-	Q_UNUSED(widget);
-
 	if (polygon().isEmpty())
 		return;
 	painter->save();
@@ -815,11 +790,8 @@ void DiveGasPressureItem::plotGasValue(int mbar, int sec, struct gasmix gasmix,
 	texts.push_back(text);
 }
 
-void DiveGasPressureItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+void DiveGasPressureItem::paint(QPainter *painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
-	Q_UNUSED(option);
-	Q_UNUSED(widget);
-
 	if (polygon().isEmpty())
 		return;
 	QPen pen;
@@ -894,9 +866,8 @@ DiveCalculatedTissue::DiveCalculatedTissue(ProfileWidget2 *widget) : DiveCalcula
 	connect(SettingsObjectWrapper::instance()->techDetails, &TechnicalDetailsSettings::calcceilingChanged, this, &DiveCalculatedTissue::setVisible);
 }
 
-void DiveCalculatedTissue::setVisible(bool visible)
+void DiveCalculatedTissue::setVisible(bool)
 {
-	Q_UNUSED(visible);
 	settingsChanged();
 }
 
@@ -1014,11 +985,8 @@ void PartialPressureGasItem::modelDataChanged(const QModelIndex &topLeft, const
 	*/
 }
 
-void PartialPressureGasItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
+void PartialPressureGasItem::paint(QPainter *painter, const QStyleOptionGraphicsItem*, QWidget*)
 {
-	Q_UNUSED(option);
-	Q_UNUSED(widget);
-
 	const qreal pWidth = 0.0;
 	painter->save();
 	painter->setPen(QPen(normalColor, pWidth));
