@@ -2,8 +2,7 @@
 #include "cylindermodel.h"
 #include "tankinfomodel.h"
 #include "models.h"
-#include "core/helpers.h"
-#include "core/dive.h"
+#include "core/qthelper.h"
 #include "core/color.h"
 #include "qt-models/diveplannermodel.h"
 #include "core/gettextfromc.h"
@@ -223,7 +222,7 @@ QVariant CylindersModel::data(const QModelIndex &index, int role) const
 				ret = get_depth_string(gas_mnd(&cyl->gasmix, prefs.bestmixend, &displayed_dive, M_OR_FT(1,1)), true);
 			break;
 		case USE:
-			ret = gettextFromC::instance()->trGettext(cylinderuse_text[cyl->cylinder_use]);
+			ret = gettextFromC::tr(cylinderuse_text[cyl->cylinder_use]);
 			break;
 		}
 		break;
@@ -428,9 +427,8 @@ bool CylindersModel::setData(const QModelIndex &index, const QVariant &value, in
 	return true;
 }
 
-int CylindersModel::rowCount(const QModelIndex &parent) const
+int CylindersModel::rowCount(const QModelIndex&) const
 {
-	Q_UNUSED(parent);
 	return rows;
 }
 
