@@ -18,6 +18,7 @@ public:
 		RUNTIME,
 		GAS,
 		CCSETPOINT,
+		DIVEMODE,
 		COLUMNS
 	};
 	enum Mode {
@@ -59,7 +60,7 @@ public:
 
 public
 slots:
-	int addStop(int millimeters = 0, int seconds = 0, int cylinderid_in = -1, int ccpoint = 0, bool entered = true);
+	int addStop(int millimeters = 0, int seconds = 0, int cylinderid_in = -1, int ccpoint = 0, bool entered = true, enum divemode_t = UNDEF_COMP_TYPE);
 	void addCylinder_clicked();
 	void setGFHigh(const int gfhigh);
 	void setGFLow(const int gflow);
