@@ -1,7 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
 #include "qt-models/diveplotdatamodel.h"
 #include "qt-models/diveplannermodel.h"
-#include "core/dive.h"
 #include "core/profile.h"
 #include "core/divelist.h"
 #include "core/color.h"
@@ -15,9 +14,8 @@ DivePlotDataModel::DivePlotDataModel(QObject *parent) :
 	memset(&plot_deco_state, 0, sizeof(struct deco_state));
 }
 
-int DivePlotDataModel::columnCount(const QModelIndex &parent) const
+int DivePlotDataModel::columnCount(const QModelIndex&) const
 {
-	Q_UNUSED(parent);
 	return COLUMNS;
 }
 
@@ -63,6 +61,8 @@ QVariant DivePlotDataModel::data(const QModelIndex &index, int role) const
 			return item.o2sensor[1].mbar / 1000.0;
 		case CCRSENSOR3:
 			return item.o2sensor[2].mbar / 1000.0;
+		case SCR_OC_PO2:
+			return item.scr_OC_pO2.mbar / 1000.0;
 		case HEARTBEAT:
 			return item.heartbeat;
 		case AMBPRESSURE:
@@ -96,9 +96,8 @@ const plot_info &DivePlotDataModel::data() const
 	return pInfo;
 }
 
-int DivePlotDataModel::rowCount(const QModelIndex &parent) const
+int DivePlotDataModel::rowCount(const QModelIndex&) const
 {
-	Q_UNUSED(parent);
 	return pInfo.nr;
 }
 
