@@ -33,6 +33,17 @@ slots:
 	void repopulate();
 };
 
+class DiveTypeSelectionModel : public QStringListModel {
+	Q_OBJECT
+public:
+	static DiveTypeSelectionModel *instance();
+	Qt::ItemFlags flags(const QModelIndex &index) const;
+	virtual QVariant data(const QModelIndex &index, int role) const;
+public
+slots:
+	void repopulate();
+};
+
 
 class LanguageModel : public QAbstractListModel {
 	Q_OBJECT
