@@ -18,6 +18,7 @@ SRC=$(pwd)
 PLATFORM=$(uname)
 
 BTSUPPORT="ON"
+DEBUGRELEASE="Debug"
 
 # deal with all the command line arguments
 while [[ $# -gt 0 ]] ; do
@@ -62,8 +63,14 @@ while [[ $# -gt 0 ]] ; do
 			# hack for Travix Mac build
 			SKIP_GOOGLEMAPS="1"
 			;;
+		-release)
+			# don't build Debug binaries
+			DEBUGRELEASE="Release"
+			;;
 		*)
 			echo "Unknown command line argument $arg"
+			echo "Usage: build.sh [-no-bt] [-build-deps] [-build-with-webkit] [-mobile] [-desktop] [-both] [-create-appdir] [-skip-googlemaps] [-release]"
+			exit 1
 			;;
 	esac
 	shift
@@ -177,7 +184,12 @@ fi
 # set up the right file name extensions
 if [ $PLATFORM = Darwin ] ; then
 	SH_LIB_EXT=dylib
-	pkg-config --exists libgit2 && LIBGIT=$(pkg-config --modversion libgit2 | cut -d. -f2)
+	if [ ! "$BUILD_DEPS" == "1" ] ; then
+		pkg-config --exists libgit2 && LIBGIT=$(pkg-config --modversion libgit2 | cut -d. -f2)
+		if [[ "$LIBGIT" > "23" ]] ; then
+			LIBGIT2_FROM_PKGCONFIG="-DLIBGIT2_FROM_PKGCONFIG=ON"
+		fi
+	fi
 else
 	SH_LIB_EXT=so
 
@@ -187,6 +199,7 @@ else
 	# this script has been run before)
 	if pkg-config --exists libgit2 ; then
 		LIBGIT=$(pkg-config --modversion libgit2 | cut -d. -f2)
+		LIBGIT2_FROM_PKGCONFIG="-DLIBGIT2_FROM_PKGCONFIG=ON"
 	fi
 	if [[ "$LIBGIT" < "24" ]] ; then
 		# maybe there's a system version that's new enough?
@@ -214,10 +227,18 @@ if [[ $PLATFORM = Darwin && "$BUILD_DEPS" == "1" ]] ; then
 	pushd libssh2
 	mkdir -p build
 	cd build
-	cmake $OLDER_MAC_CMAKE -DCMAKE_INSTALL_PREFIX=$INSTALL_ROOT -DCMAKE_BUILD_TYPE=Release -DBUILD_SHARED_LIBS=ON -DBUILD_TESTING=OFF -DBUILD_EXAMPLES=OFF ..
+	cmake $OLDER_MAC_CMAKE -DCMAKE_INSTALL_PREFIX=$INSTALL_ROOT -DCMAKE_BUILD_TYPE=$DEBUGRELEASE -DBUILD_SHARED_LIBS=ON -DBUILD_TESTING=OFF -DBUILD_EXAMPLES=OFF ..
 	make -j4
 	make install
 	popd
+	if [ $PLATFORM = Darwin ] ; then
+		# in order for macdeployqt to do its job correctly, we need the full path in the dylib ID
+		cd $INSTALL_ROOT/lib
+		NAME=$(otool -L libssh2.dylib | grep -v : | head -1 | cut -f1 -d\  | tr -d '\t')
+		echo $NAME | if grep -v / > /dev/null 2>&1 ; then
+			install_name_tool -id "$INSTALL_ROOT/lib/$NAME" "$INSTALL_ROOT/lib/$NAME"
+		fi
+	fi
 fi
 
 if [[ "$LIBGIT" < "24" ]] ; then
@@ -229,7 +250,7 @@ if [[ "$LIBGIT" < "24" ]] ; then
 	pushd libgit2
 	mkdir -p build
 	cd build
-	cmake $OLDER_MAC_CMAKE -DCMAKE_INSTALL_PREFIX=$INSTALL_ROOT -DCMAKE_BUILD_TYPE=Release -DBUILD_CLAR=OFF ..
+	cmake $OLDER_MAC_CMAKE -DCMAKE_INSTALL_PREFIX=$INSTALL_ROOT -DCMAKE_BUILD_TYPE=$DEBUGRELEASE -DBUILD_CLAR=OFF ..
 	make -j4
 	make install
 	popd
@@ -238,7 +259,7 @@ if [[ "$LIBGIT" < "24" ]] ; then
 		# in order for macdeployqt to do its job correctly, we need the full path in the dylib ID
 		cd $INSTALL_ROOT/lib
 		NAME=$(otool -L libgit2.dylib | grep -v : | head -1 | cut -f1 -d\  | tr -d '\t')
-		echo $NAME | if grep / > /dev/null 2>&1 ; then
+		echo $NAME | if grep -v / > /dev/null 2>&1 ; then
 			install_name_tool -id "$INSTALL_ROOT/lib/$NAME" "$INSTALL_ROOT/lib/$NAME"
 		fi
 	fi
@@ -390,7 +411,7 @@ if [ "$BUILDGRANTLEE" = "1" ] ; then
 	fi
 	mkdir -p build
 	cd build
-	cmake $OLDER_MAC_CMAKE -DCMAKE_BUILD_TYPE=Release \
+	cmake $OLDER_MAC_CMAKE -DCMAKE_BUILD_TYPE=$DEBUGRELEASE \
 		-DCMAKE_INSTALL_PREFIX=$INSTALL_ROOT \
 		-DBUILD_TESTS=NO \
 		$SRC/grantlee
@@ -448,7 +469,7 @@ for (( i=0 ; i < ${#BUILDS[@]} ; i++ )) ; do
 	mkdir -p $SRC/subsurface/$BUILDDIR
 	cd $SRC/subsurface/$BUILDDIR
 	export CMAKE_PREFIX_PATH="$INSTALL_ROOT/lib/cmake;${CMAKE_PREFIX_PATH}"
-	cmake -DCMAKE_BUILD_TYPE=Debug .. \
+	cmake -DCMAKE_BUILD_TYPE=$DEBUGRELEASE .. \
 		-DSUBSURFACE_TARGET_EXECUTABLE=$SUBSURFACE_EXECUTABLE \
 		${LIBGIT_ARGS} \
 		-DLIBDIVECOMPUTER_INCLUDE_DIR=$INSTALL_ROOT/include \
@@ -456,7 +477,7 @@ for (( i=0 ; i < ${#BUILDS[@]} ; i++ )) ; do
 		-DCMAKE_PREFIX_PATH=$CMAKE_PREFIX_PATH \
 		-DBTSUPPORT=${BTSUPPORT} \
 		-DCMAKE_INSTALL_PREFIX=${INSTALL_ROOT} \
-		-DLIBGIT2_FROM_PKGCONFIG=ON \
+		$LIBGIT2_FROM_PKGCONFIG \
 		-DFORCE_LIBSSH=OFF \
 		$PRINTING $EXTRA_OPTS
 
