@@ -6,7 +6,7 @@ set -e
 # this gets executed by Travis when building an App for Mac
 # it gets started from inside the subsurface directory
 
-export QT_ROOT=${TRAVIS_BUILD_DIR}/Qt/5.9.1
+export QT_ROOT=${TRAVIS_BUILD_DIR}/Qt/5.11.1/clang_64
 export PATH=$QT_ROOT/bin:$PATH # Make sure correct qmake is found on the $PATH
 export CMAKE_PREFIX_PATH=$QT_ROOT/lib/cmake
 export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig:$PKG_CONFIG_PATH
@@ -15,7 +15,7 @@ export PKG_CONFIG_PATH=/usr/local/lib/pkgconfig:$PKG_CONFIG_PATH
 cd ${TRAVIS_BUILD_DIR}/..
 DIR=$(pwd)
 
-bash -e -x ./subsurface/scripts/build.sh -desktop -build-with-webkit
+bash -e -x ./subsurface/scripts/build.sh -desktop -build-with-webkit -release
 
 cd ${TRAVIS_BUILD_DIR}/build
 
