@@ -14,41 +14,19 @@ if [ ! -d "$SRC/subsurface" ] || [ ! -d "mobile-widgets" ] || [ ! -d "core" ] ;
 	exit 1
 fi
 
-if [ "$1" = "-nopull" ] ; then
-	NOPULL=1
-fi
-
 # now bring in the latest Kirigami mobile components plus a couple of icons that we need
 # first, get the latest from upstream
 # yes, this is a bit overkill as we clone a lot of stuff for just a few files, but this way
 # we stop having to manually merge our code with upstream all the time
 # as we get closer to shipping a production version we'll likely check out specific tags
 # or SHAs from upstream
-cd $SRC
-if [ ! -d kirigami ] ; then
-	git clone -b master https://github.com/KDE/kirigami.git
-fi
-if [ "$NOPULL" = "" ] ; then
-	pushd kirigami
-	git checkout master
-	git pull origin master
-	# if we want to pin a specific Kirigami version, we can do this here
-	git checkout 38a9dec7317945e5751c86a6c54de787c261e024
-	popd
-fi
-if [ ! -d breeze-icons ] ; then
-	git clone https://github.com/kde/breeze-icons
-fi
-if [ "$NOPULL" = "" ] ; then
-	pushd breeze-icons
-	git pull
-	popd
-fi
+./scripts/get-dep-lib.sh single .. kirigami
+./scripts/get-dep-lib.sh single .. breeze-icons
 
 # now copy the components and a couple of icons into plae
 MC=$SRC/subsurface/mobile-widgets/qml/kirigami
-PMMC=kirigami
-BREEZE=breeze-icons
+PMMC=../kirigami
+BREEZE=../breeze-icons
 
 rm -rf $MC
 mkdir -p $MC/icons
@@ -73,13 +51,17 @@ cp $BREEZE/icons/actions/22/overflow-menu.svg $MC/icons
 
 # kirigami now needs the breeze-icons internally as well
 pushd $MC
-ln -s $SRC/$BREEZE .
+ln -s $SRC/breeze-icons .
 
 # do not show the action buttons when the keyboard is open
 sed -i -e "s/visible: root.action/visible: root.action \&\& \!Qt.inputMethod.visible/g" src/controls/private/ActionButton.qml
 sed -i -e "s/visible: root.leftAction/visible: root.leftAction \&\& \!Qt.inputMethod.visible/g" src/controls/private/ActionButton.qml
 sed -i -e "s/visible: root.rightAction/visible: root.rightAction \&\& \!Qt.inputMethod.visible/g" src/controls/private/ActionButton.qml
 
+# kirigami hack: passive notification hijacks area even after disabled.
+# https://bugs.kde.org/show_bug.cgi?id=394204
+sed -i -e "s/width: backgroundRect/enabled: root.enabled;    width: backgroundRect/g" src/controls/templates/private/PassiveNotification.qml
+
 # another hack. Do not include the Kirigami resources (on static build). It causes
 # double defined symbols in our setting. I would like a nicer fix for this
 # issue, but failed to find one. For example, not adding the resource in
@@ -88,6 +70,14 @@ sed -i -e "s/visible: root.rightAction/visible: root.rightAction \&\& \!Qt.input
 # so it seems some Kirigami weirdness (but their staticcmake example compiles
 # correctly).
 sed -i -e "s/#include <qrc_kirigami.cpp>/\/\/#include <qrc_kirigami.cpp>/" src/kirigamiplugin.cpp
+
+# next hack - we want to use the topContent in the GlobalDrawer for our
+# own image / logo / text (in part because the logo display got broken, in
+# part because we want a second line of text to show the account ID
+# for this to work we need to remove the margin that the GlobalDrawer
+# forces around the topContent
+patch -p0 < $SRC/subsurface/scripts/kirigami.diff
+
 popd
 
 echo org.kde.plasma.kirigami synced from upstream
