@@ -6,7 +6,6 @@
 #include <stdlib.h>
 #include <time.h>
 
-#include "core/dive.h"
 #include "core/qt-gui.h"
 #include "core/subsurfacestartup.h"
 #include "desktop-widgets/mainwindow.h"
@@ -41,8 +40,7 @@ int main(int argc, char **argv)
 	int i;
 	bool no_filenames = true;
 	QLoggingCategory::setFilterRules(QStringLiteral("qt.bluetooth* = true"));
-	QApplication *application = new QApplication(argc, argv);
-	(void)application;
+	new QApplication(argc, argv);
 	QStringList files;
 	QStringList importedFiles;
 	QStringList arguments = QCoreApplication::arguments();
@@ -221,9 +219,8 @@ exit:
 }
 
 // install this message handler primarily so that the Windows build can log to files
-void messageHandler(QtMsgType type, const QMessageLogContext &ctx, const QString &msg)
+void messageHandler(QtMsgType type, const QMessageLogContext&, const QString &msg)
 {
-	Q_UNUSED(ctx);
 	QByteArray localMsg = msg.toUtf8();
 	switch (type) {
 	case QtDebugMsg:
