@@ -1,6 +1,6 @@
 // SPDX-License-Identifier: GPL-2.0
-#ifndef TESTDIVESITEDUPLICATION_H
-#define TESTDIVESITEDUPLICATION_H
+#ifndef TESTPREFERENCES_H
+#define TESTPREFERENCES_H
 
 #include <QTest>
 #include <functional>
@@ -13,4 +13,4 @@ private slots:
 	void testPreferences();
 };
 
-#endif // TESTDIVESITEDUPLICATION_H
+#endif // TESTPREFERENCES_H
